@@ -58,6 +58,7 @@ static void register_panel_update(GtkWidget *widget, gpointer user_data);
 static void register_panel_export_csv(GtkWidget *widget, gpointer user_data);
 
 static void register_panel_make_archive(GtkWidget *widget, gpointer user_data);
+static void register_panel_make_assignment(GtkWidget *widget, gpointer user_data);
 
 static void status_selected_foreach_func (GtkTreeModel	*model, GtkTreePath	 *path, GtkTreeIter	 *iter, gpointer userdata);
 
@@ -154,6 +155,12 @@ struct register_panel_data *data = user_data;
 	register_panel_make_archive(data->window, NULL);
 }
 
+static void register_panel_action_createassignment(GtkMenuItem *menuitem, gpointer     user_data)
+{
+struct register_panel_data *data = user_data;
+
+	register_panel_make_assignment(data->window, NULL);
+}
 
 
 static void register_panel_action_exportcsv(GtkMenuItem *menuitem, gpointer     user_data)
@@ -311,7 +318,7 @@ gint count;
 			GTK_WINDOW(data->window),
 			_("Check internal transfer result"),
 			_("Inconsistency were found: %d\n"
-			  "do you want to review and fix ?"),
+			  "do you want to review and fix?"),
 			count
 			);
 
@@ -336,6 +343,16 @@ gint count;
 }
 
 
+static void register_panel_action_viewsplit(GtkMenuItem *menuitem, gpointer     user_data)
+{
+struct register_panel_data *data = user_data;
+Transaction *ope;
+
+	ope = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+	if(ope != NULL)
+		ui_split_view_dialog(data->window, ope);
+}
+
 /* = = = = = = = = end future version = = = = = = = = */
 
 
@@ -384,7 +401,7 @@ gint result;
 	if(result == GTK_RESPONSE_OK)
 	{
 		account_convert_euro(data->acc);
-		register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_BALANCE));
+		register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_BALANCE));
 	}
 }
 
@@ -431,7 +448,7 @@ gint count;
 	g_list_free(selection);
 
 	if(count > 0 )
-		register_panel_update(data->window, GINT_TO_POINTER(UF_SENSITIVE));
+		register_panel_update(data->window, GINT_TO_POINTER(FLG_REG_SENSITIVE));
 	
 }
 
@@ -464,7 +481,7 @@ GList *list;
 		list = g_list_next(list);
 	}
 
-	register_panel_update(data->window, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
+	register_panel_update(data->window, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 	
 }
 
@@ -595,13 +612,77 @@ GtkWidget *dialog;
 
 	gtk_widget_destroy (dialog);
 	
-	register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_BALANCE));
+	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_BALANCE));
+}
+
+
+static void register_panel_make_assignment(GtkWidget *widget, gpointer user_data)
+{
+struct register_panel_data *data;
+GtkTreeModel *model;
+GList *selection, *list;
+gint result, count;
+
+	DB( g_print("\n[register] make assignment\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+
+	count = gtk_tree_selection_count_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope)));
+
+	if( count > 0 )
+	{
+
+		result = ui_dialog_msg_confirm_alert(
+				GTK_WINDOW(data->window),
+				NULL,
+				_("Do you want to create an assignment with\neach of the selected transaction?"),
+				_("_Create")
+			);
+
+	/*
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("%d archives will be created"),
+			GLOBALS->changes_count
+			);
+	*/
+
+		if(result == GTK_RESPONSE_OK)
+		{
+			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
+			selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope)), &model);
+
+			list = g_list_first(selection);
+			while(list != NULL)
+			{
+			Assign *item;
+			Transaction *ope;
+			GtkTreeIter iter;
+
+				gtk_tree_model_get_iter(model, &iter, list->data);
+				gtk_tree_model_get(model, &iter, MODEL_TXN_POINTER, &ope, -1);
+
+				DB( g_print(" create assignment %s %.2f\n", ope->memo, ope->amount) );
+
+				//TODO: migrate to hb-assign
+				item = da_asg_malloc();
+
+				da_asg_init_from_transaction(item, ope);
+				
+				da_asg_append(item);
+
+				GLOBALS->changes_count++;
+
+				list = g_list_next(list);
+			}
+
+			g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+			g_list_free(selection);
+		}
+	}
 }
 
 
-/*
-** make an archive with the active transaction
-*/
 static void register_panel_make_archive(GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data;
@@ -622,7 +703,7 @@ gint result, count;
 		result = ui_dialog_msg_confirm_alert(
 				GTK_WINDOW(data->window),
 				NULL,
-				_("Do you want to create a template with\neach of the selected transaction ?"),
+				_("Do you want to create a template with\neach of the selected transaction?"),
 				_("_Create")
 			);
 
@@ -652,7 +733,7 @@ gint result, count;
 
 				item = da_archive_malloc();
 
-				da_archive_init_from_transaction(item, ope);
+				da_archive_init_from_transaction(item, ope, TRUE);
 
 				//GLOBALS->arc_list = g_list_append(GLOBALS->arc_list, item);
 				da_archive_append_new(item);
@@ -671,15 +752,13 @@ gint result, count;
 
 static void register_panel_move_up(GtkWidget *widget, gpointer user_data)
 {
-struct register_panel_data *data;
+struct register_panel_data *data = user_data;
 Transaction *txn = NULL;
 Transaction *prevtxn = NULL;
 gint count = 0;
 	
 	DB( g_print("\n[register] move up\n\n") );
 
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
 	txn = list_txn_get_surround_transaction(GTK_TREE_VIEW(data->LV_ope), &prevtxn, NULL);
 	if( txn && prevtxn )
 	{
@@ -698,22 +777,20 @@ gint count = 0;
 	if( count > 0 )
 	{
 		data->do_sort = TRUE;
-		register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE|UF_BALANCE));
+		register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE|FLG_REG_BALANCE));
 	}		
 }
 
 
 static void register_panel_move_down(GtkWidget *widget, gpointer user_data)
 {
-struct register_panel_data *data;
+struct register_panel_data *data = user_data;
 Transaction *txn = NULL;
 Transaction *nexttxn = NULL;
 gint count = 0;
 
 	DB( g_print("\n[register] move down\n\n") );
 
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
 	txn = list_txn_get_surround_transaction(GTK_TREE_VIEW(data->LV_ope), NULL, &nexttxn);
 	if( txn && nexttxn )
 	{
@@ -732,7 +809,7 @@ gint count = 0;
 	if( count > 0 )
 	{
 		data->do_sort = TRUE;
-		register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE|UF_BALANCE));
+		register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE|FLG_REG_BALANCE));
 	}		
 }
 
@@ -789,7 +866,7 @@ gint range;
 		{
 			register_panel_collect_filtered_txn(data->LV_ope, FALSE);
 			register_panel_listview_populate(data->LV_ope);
-			register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
+			register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 		}
 	}
 }
@@ -854,9 +931,15 @@ struct register_panel_data *data;
 	g_signal_handler_block(data->CY_type, data->handler_id[HID_TYPE]);
 	g_signal_handler_block(data->CY_status, data->handler_id[HID_STATUS]);
 
+	DB( g_print(" - set range : %d\n", data->filter->range) );
+	DB( g_print(" - set type  : %d\n", data->filter->type) );
+	DB( g_print(" - set status: %d\n", data->filter->rawstatus) );
+
 	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), data->filter->range);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_type), data->filter->type);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), data->filter->rawstatus);
+	//# #1873324 register status quick filter do not reset 
+	//gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), data->filter->rawstatus);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), data->filter->status);
 
 	g_signal_handler_unblock(data->CY_status, data->handler_id[HID_STATUS]);
 	g_signal_handler_unblock(data->CY_type, data->handler_id[HID_TYPE]);
@@ -1095,7 +1178,7 @@ guint i, qs_flag;
 		g_free(daterange);
 	}
 	
-	register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
+	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 
 }
 
@@ -1273,7 +1356,7 @@ static void register_panel_add_after_propagate(struct register_panel_data *data,
 				if( child )
 				{
 					register_panel_add_single_transaction(accwin, child);
-					register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(UF_BALANCE));
+					register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(FLG_REG_BALANCE));
 				}
 			}
 		}
@@ -1347,6 +1430,8 @@ gboolean result;
 			{
 				DB( g_print("(transaction) add multiple\n") );
 				data->cur_ope = da_transaction_malloc();
+				// miss from 5.2.8 ??
+				//da_transaction_set_default_template(src_txn);
 				type = TXN_DLG_ACTION_ADD;
 				result = HB_RESPONSE_ADD;
 			}
@@ -1354,7 +1439,11 @@ gboolean result;
 			{
 				DB( g_print("(transaction) inherit multiple\n") );
 				data->cur_ope = da_transaction_clone(list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope)));
-				//#1432204
+				//#1873311 inherit+kepplastdate=OFF = today
+				if( PREFS->heritdate == FALSE ) 
+					data->cur_ope->date = GLOBALS->today;
+
+				//#1432204 inherit => status none
 				data->cur_ope->status = TXN_STATUS_NONE;
 				type = TXN_DLG_ACTION_INHERIT;
 				result = HB_RESPONSE_ADDKEEP;
@@ -1368,18 +1457,13 @@ gboolean result;
 				{
 					da_transaction_init(data->cur_ope, kacc);
 				}
-				//#1858945 if keep date=0 we should override with today
-				else
-				if( result == HB_RESPONSE_ADDKEEP )
-				{
-					//#318733 #1335285
-					if( PREFS->heritdate == FALSE ) 
-						data->cur_ope->date = GLOBALS->today;
-				}
 
 				deftransaction_set_transaction(dialog, data->cur_ope);
 
 				result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+				DB( g_print(" - dialog result is %d\n", result) );
+
 				if(result == HB_RESPONSE_ADD || result == HB_RESPONSE_ADDKEEP || result == GTK_RESPONSE_ACCEPT)
 				{
 				Transaction *add_txn;
@@ -1391,9 +1475,11 @@ gboolean result;
 					if(PREFS->txn_showconfirm)
 						deftransaction_external_confirm(dialog, add_txn);
 
+					DB( g_print(" - added 1 transaction to %d\n", add_txn->kacc) );
+
 					register_panel_add_after_propagate(data, add_txn);
 
-					register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+					register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 					//#1667201 already done into transaction_add
 					//data->acc->flags |= AF_ADDED;
 					GLOBALS->changes_count++;
@@ -1443,7 +1529,7 @@ gboolean result;
 						if(accwin)
 						{
 							register_panel_add_single_transaction(accwin, new_txn);
-							register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(UF_BALANCE));
+							register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(FLG_REG_BALANCE));
 						}
 					}
 
@@ -1454,13 +1540,13 @@ gboolean result;
 
 						if(accwin)
 						{
-							register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(UF_BALANCE));
+							register_panel_update(GTK_WIDGET(accwin), GINT_TO_POINTER(FLG_REG_BALANCE));
 						}
 					}
 
 					//da_transaction_copy(new_txn, old_txn);
 
-					register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+					register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 
 					transaction_changed(new_txn);
 
@@ -1483,7 +1569,7 @@ gboolean result;
 			result = ui_dialog_msg_confirm_alert(
 					GTK_WINDOW(data->window),
 					NULL,
-					_("Do you want to delete\neach of the selected transaction ?"),
+					_("Do you want to delete\neach of the selected transaction?"),
 					_("_Delete")
 				);
 
@@ -1547,7 +1633,7 @@ gboolean result;
 
 				g_signal_handlers_unblock_by_func (G_OBJECT (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope))), G_CALLBACK (register_panel_selection), NULL);
 				
-				register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+				register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 			}
 		}
 		break;
@@ -1583,7 +1669,7 @@ gboolean result;
 				gtk_widget_queue_draw (data->LV_ope);
 				//gtk_widget_queue_resize (data->LV_acc);
 
-				register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+				register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 
 				GLOBALS->changes_count++;
 			}
@@ -1604,7 +1690,7 @@ gboolean result;
 			gtk_widget_queue_draw (data->LV_ope);
 			//gtk_widget_queue_resize (data->LV_acc);
 
-			register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+			register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 
 			GLOBALS->changes_count++;
 		}
@@ -1641,7 +1727,7 @@ gboolean result;
 				gtk_widget_queue_draw (data->LV_ope);
 				//gtk_widget_queue_resize (data->LV_acc);
 
-				register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
+				register_panel_update(widget, GINT_TO_POINTER(FLG_REG_BALANCE));
 
 				GLOBALS->changes_count++;
 			}
@@ -1656,7 +1742,7 @@ gboolean result;
 			{
 				register_panel_collect_filtered_txn(data->LV_ope, TRUE);
 				register_panel_listview_populate(data->LV_ope);
-				register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
+				register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 
 				g_signal_handler_block(data->CY_range, data->handler_id[HID_RANGE]);
 				hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
@@ -1684,7 +1770,7 @@ struct register_panel_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_BALANCE));
+	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_BALANCE));
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_ope));
 }
 
@@ -1695,7 +1781,7 @@ static void register_panel_selection(GtkTreeSelection *treeselection, gpointer u
 	DB( g_print("\n[register] selection changed cb\n") );
 
 
-	register_panel_update(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(UF_SENSITIVE));
+	register_panel_update(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), GINT_TO_POINTER(FLG_REG_SENSITIVE));
 
 }
 
@@ -1717,17 +1803,17 @@ gint count = 0;
 	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
 	/* set window title */
-	if(flags & UF_TITLE)
+	if(flags & FLG_REG_TITLE)
 	{
-		DB( g_print(" - UF_TITLE\n") );
+		DB( g_print(" - FLG_REG_TITLE\n") );
 
 	}
 
 
 	/* update toolbar & list */
-	if(flags & UF_VISUAL)
+	if(flags & FLG_REG_VISUAL)
 	{
-		DB( g_print(" - UF_VISUAL\n") );
+		DB( g_print(" - FLG_REG_VISUAL\n") );
 
 		if(PREFS->toolbar_style == 0)
 			gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
@@ -1746,9 +1832,9 @@ gint count = 0;
 	}
 
 	/* update balances */
-	if(flags & UF_BALANCE)
+	if(flags & FLG_REG_BALANCE)
 	{
-		DB( g_print(" - UF_BALANCE\n") );
+		DB( g_print(" - FLG_REG_BALANCE\n") );
 
 		if(data->showall == FALSE)
 		{
@@ -1787,14 +1873,15 @@ gint count = 0;
 	}
 
 	/* update disabled things */
-	if(flags & UF_SENSITIVE)
+	if(flags & FLG_REG_SENSITIVE)
 	{
-	gboolean sensitive;
+	gboolean sensitive, psensitive, nsensitive;
 	GtkTreeModel *model;
 	gint sort_column_id;
 	GtkSortType order;
+	Transaction *ope;
 
-		DB( g_print(" - UF_SENSITIVE\n") );
+		DB( g_print(" - FLG_REG_SENSITIVE\n") );
 
 		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope));
 		count = gtk_tree_selection_count_selected_rows(selection);
@@ -1803,10 +1890,14 @@ gint count = 0;
 		//showall part
 		visible = !data->showall;
 		hb_widget_visible(data->MI_exportpdf, visible);
+		hb_widget_visible(data->MI_print, visible);
 		hb_widget_visible(data->MI_exportqif, visible);
 		hb_widget_visible(data->MI_exportcsv, visible);
-		hb_widget_visible(data->MI_chkintxfer, visible);
+		//tools
 		hb_widget_visible(data->MI_markdup, visible);
+		hb_widget_visible(data->MI_chkintxfer, visible);
+		//#1873248 Auto. assignments faulty visible on 'All transactions' window
+		hb_widget_visible(data->MI_autoassign, visible);
 		
 		//5.3.1 if closed account : disable any change
 		sensitive =  TRUE;
@@ -1817,26 +1908,39 @@ gint count = 0;
 		gtk_widget_set_sensitive(data->ME_menuedit, sensitive);
 		gtk_widget_set_sensitive(data->ME_menutxn, sensitive);
 		gtk_widget_set_sensitive(data->ME_menutools, sensitive);
+		gtk_widget_set_sensitive(data->ME_popmenu, sensitive);
 
 		// multiple: disable inherit, edit
 		sensitive = (count != 1 ) ? FALSE : TRUE;
 		gtk_widget_set_sensitive(data->MI_herit, sensitive);
+		gtk_widget_set_sensitive(data->MI_popherit, sensitive);
 		gtk_widget_set_sensitive(data->MI_edit, sensitive);
-
+		gtk_widget_set_sensitive(data->MI_popedit, sensitive);
 		gtk_widget_set_sensitive(data->BT_herit, sensitive);
 		gtk_widget_set_sensitive(data->BT_edit, sensitive);
+
+		//txn have split
+		ope = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+		sensitive = (count == 1) && (ope != NULL) && (ope->flags & OF_SPLIT) ? TRUE : FALSE;
+		gtk_widget_set_sensitive(data->MI_popviewsplit, sensitive);
 		
 		// single: disable multiedit
 		sensitive = (count <= 1 ) ? FALSE : TRUE;
 		gtk_widget_set_sensitive(data->MI_multiedit, sensitive);
+		gtk_widget_set_sensitive(data->MI_popmultiedit, sensitive);
 		gtk_widget_set_sensitive(data->BT_multiedit, sensitive);
-		
+
 		// no selection: disable reconcile, delete
 		sensitive = (count > 0 ) ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_copy, sensitive);
 		gtk_widget_set_sensitive(data->ME_menustatus, sensitive);
+		gtk_widget_set_sensitive(data->ME_popmenustatus, sensitive);
 		gtk_widget_set_sensitive(data->MI_delete, sensitive);
+		gtk_widget_set_sensitive(data->MI_popdelete, sensitive);
+		gtk_widget_set_sensitive(data->MI_assign, sensitive);
+		gtk_widget_set_sensitive(data->MI_popassign, sensitive);
 		gtk_widget_set_sensitive(data->MI_template, sensitive);
+		gtk_widget_set_sensitive(data->MI_poptemplate, sensitive);
 		gtk_widget_set_sensitive(data->BT_delete ,sensitive);
 		gtk_widget_set_sensitive(data->BT_clear, sensitive);
 		gtk_widget_set_sensitive(data->BT_reconcile, sensitive);
@@ -1853,34 +1957,42 @@ gint count = 0;
 			visible = FALSE;
 		hb_widget_visible(data->MI_conveuro, visible);
 
-		//move up/down button
-		visible = (count == 1 ) ? TRUE : FALSE;
-		model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
-		gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), &sort_column_id, &order);
-		if( (data->showall == TRUE) || (sort_column_id != LST_DSPOPE_DATE) )
-			visible = FALSE;
+		//move up/down button : not when showall and when sort is not date
+		visible = FALSE;
+		psensitive = FALSE;
+		nsensitive = FALSE;
+		if( count == 1 && data->showall == FALSE )
+		{
+		Transaction *prevtxn, *nexttxn;
+
+			visible = TRUE;
+			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
+			gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), &sort_column_id, &order);
+			if( (data->showall == TRUE) || (sort_column_id != LST_DSPOPE_DATE) )
+				visible = FALSE;
+
+			prevtxn = NULL; nexttxn = NULL;
+			Transaction *txn = list_txn_get_surround_transaction(GTK_TREE_VIEW(data->LV_ope), &prevtxn, &nexttxn);
+
+			if( prevtxn && txn )
+			{
+				psensitive = (prevtxn->date == txn->date) ? TRUE : FALSE;
+			}
+
+			if( nexttxn && txn )
+			{
+				nsensitive = (nexttxn->date == txn->date) ? TRUE : FALSE;
+			}
+		}
+
 		hb_widget_visible(data->BT_up, visible);
 		hb_widget_visible(data->BT_down, visible);
-
-		//test next txn
-		Transaction *prevtxn, *nexttxn;
-		prevtxn = NULL; nexttxn = NULL;
-		Transaction *txn = list_txn_get_surround_transaction(GTK_TREE_VIEW(data->LV_ope), &prevtxn, &nexttxn);
-
-		sensitive = FALSE;
-		if( prevtxn && txn )
-		{
-			sensitive = (prevtxn->date == txn->date) ? TRUE : FALSE;
-		}
-		gtk_widget_set_sensitive(data->BT_up, sensitive);
-	
-		sensitive = FALSE;
-		if( nexttxn && txn )
-		{
-			sensitive = (nexttxn->date == txn->date) ? TRUE : FALSE;
-		}
-		gtk_widget_set_sensitive(data->BT_down, sensitive);
-		
+		hb_widget_visible(data->MI_poptxnup, visible);
+		hb_widget_visible(data->MI_poptxndown, visible);
+		gtk_widget_set_sensitive(data->MI_poptxnup, psensitive);
+		gtk_widget_set_sensitive(data->BT_up, psensitive);
+		gtk_widget_set_sensitive(data->MI_poptxndown, nsensitive);
+		gtk_widget_set_sensitive(data->BT_down, nsensitive);
 	}
 
 	//#1835588
@@ -1892,7 +2004,7 @@ gint count = 0;
 
 	
 	/* update fltinfo */
-	DB( g_print(" - UF_INFOBAR\n") );
+	DB( g_print(" - FLG_REG_INFOBAR\n") );
 
 
 	DB( g_print(" - statusbar\n") );
@@ -2019,39 +2131,6 @@ Transaction *ope;
 }
 
 
-/*
-static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWidget *menu)
-{
-
-	if (event->button == 3)
-	{
-
-
-		if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview),
-			(gint) event->x, (gint) event->y, &path, NULL, NULL, NULL))
-		{
-			gtk_tree_view_set_cursor (GTK_TREE_VIEW (treeview), path, NULL, FALSE);
-			gtk_tree_path_free (path);
-		}
-
-
-
-
-				gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,
-												event->button, event->time);
-
-				// On indique à l'appelant que l'on a géré cet événement.
-
-				return TRUE;
-		}
-
-		// On indique à l'appelant que l'on n'a pas géré cet événement.
-
-		return FALSE;
-}
-*/
-
-
 /*
 ** populate the account window
 */
@@ -2089,7 +2168,7 @@ struct register_panel_data *data;
 	register_panel_cb_filter_reset(widget, user_data);
 
 	DB( g_print(" - call update visual\n") );
-	register_panel_update(widget, GINT_TO_POINTER(UF_VISUAL|UF_SENSITIVE));
+	register_panel_update(widget, GINT_TO_POINTER(FLG_REG_VISUAL|FLG_REG_SENSITIVE));
 
 }
 
@@ -2134,7 +2213,7 @@ struct register_panel_data *data;
 
 		//register_panel_collect_filtered_txn(data->LV_ope);
 		//register_panel_listview_populate(data->LV_ope);
-		//register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
+		//register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 	}
 
 
@@ -2195,7 +2274,7 @@ struct register_panel_data *data;
 
 
 	//our global list has changed, so update the treeview
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_REFRESHALL));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 
 	return FALSE;
 }
@@ -2209,6 +2288,106 @@ struct register_panel_data *data = user_data;
 }
 
 
+static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWidget *menu)
+{
+
+	
+	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
+	{
+
+		// check we are not in the header but in bin window
+		 if (event->window == gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget)))
+		{
+			#if( (GTK_MAJOR_VERSION == 3) && (GTK_MINOR_VERSION >= 22) )
+				gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *)event);
+			#else
+				gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, event->button, event->time);
+			#endif
+				// On indique à l'appelant que l'on a géré cet événement.
+
+				return TRUE;
+		}
+
+		// On indique à l'appelant que l'on n'a pas géré cet événement.
+	}
+		return FALSE;
+}
+
+
+static GtkWidget *
+register_panel_popmenu_create(struct register_panel_data *data)
+{
+GtkWidget *menu, *submenu;
+GtkWidget *menuitem;
+//GtkAccelGroup *accel_group = NULL;
+
+	//accel_group = gtk_accel_group_new();
+	//gtk_window_add_accel_group(GTK_WINDOW(data->window), accel_group);
+	
+	menu = gtk_menu_new();
+	data->ME_popmenu = menu;
+
+	menuitem = hbtk_menu_add_menuitem (menu,  _("_Add...") );
+	data->MI_popadd = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Inherit..."));
+	data->MI_popherit = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Edit...") );
+	data->MI_popedit = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Multiple Edit..."));
+	data->MI_popmultiedit = menuitem;
+	
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
+	
+	submenu = hbtk_menubar_add_menu(menu, _("_Status"), &data->ME_popmenustatus);
+	
+	menuitem = hbtk_menu_add_menuitem (submenu, _("_None"));
+	data->MI_popstatnone = menuitem;
+	menuitem = hbtk_menu_add_menuitem (submenu, _("_Cleared"));
+	data->MI_popstatclear = menuitem;
+	menuitem = hbtk_menu_add_menuitem (submenu, _("_Reconciled"));
+	data->MI_popstatrecon = menuitem;
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
+
+	menuitem = hbtk_menu_add_menuitem (menu, _("View _Split"));
+	data->MI_popviewsplit = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("Create template..."));
+	data->MI_poptemplate = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("Create assignment..."));
+	data->MI_popassign = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Delete...")	);
+	data->MI_popdelete = menuitem;
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
+
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Up"));
+	data->MI_poptxnup = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("_Down"));
+	data->MI_poptxndown = menuitem;
+
+	gtk_widget_show_all(menu);
+
+	g_signal_connect (data->MI_popadd       , "activate", G_CALLBACK (register_panel_action_add), (gpointer)data);
+	g_signal_connect (data->MI_popherit     , "activate", G_CALLBACK (register_panel_action_inherit), (gpointer)data);
+	g_signal_connect (data->MI_popedit      , "activate", G_CALLBACK (register_panel_action_edit), (gpointer)data);
+	g_signal_connect (data->MI_popmultiedit , "activate", G_CALLBACK (register_panel_action_multiedit), (gpointer)data);
+
+	g_signal_connect (data->MI_popstatnone  , "activate", G_CALLBACK (register_panel_action_none), (gpointer)data);
+	g_signal_connect (data->MI_popstatclear , "activate", G_CALLBACK (register_panel_action_clear), (gpointer)data);
+	g_signal_connect (data->MI_popstatrecon , "activate", G_CALLBACK (register_panel_action_reconcile), (gpointer)data);
+
+	g_signal_connect (data->MI_popviewsplit , "activate", G_CALLBACK (register_panel_action_viewsplit), (gpointer)data);
+	g_signal_connect (data->MI_poptemplate  , "activate", G_CALLBACK (register_panel_action_createtemplate), (gpointer)data);
+	g_signal_connect (data->MI_popassign    , "activate", G_CALLBACK (register_panel_action_createassignment), (gpointer)data);
+	g_signal_connect (data->MI_popdelete    , "activate", G_CALLBACK (register_panel_action_delete), (gpointer)data);
+
+	g_signal_connect (data->MI_poptxnup     , "activate", G_CALLBACK (register_panel_move_up), (gpointer)data);
+	g_signal_connect (data->MI_poptxndown   , "activate", G_CALLBACK (register_panel_move_down), (gpointer)data);
+
+	return menu;
+}
+
+
 static GtkWidget *
 register_panel_menubar_create(struct register_panel_data *data)
 {
@@ -2229,6 +2408,8 @@ GtkAccelGroup *accel_group = NULL;
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
 		data->MI_exportpdf = hbtk_menu_add_menuitem(menu, _("Export as PDF...") );
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
+		data->MI_print = menuitem = hbtk_menu_add_menuitem(menu, _("Print...") );
+		gtk_widget_add_accelerator(menuitem, "activate", accel_group, GDK_KEY_p, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 		data->MI_close = menuitem = hbtk_menu_add_menuitem(menu, _("_Close") );
 		gtk_widget_add_accelerator(menuitem, "activate", accel_group, GDK_KEY_w, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE); 
 
@@ -2263,6 +2444,7 @@ GtkAccelGroup *accel_group = NULL;
 			gtk_widget_add_accelerator(menuitem, "activate", accel_group, GDK_KEY_r, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 		data->MI_multiedit = hbtk_menu_add_menuitem(menu, _("_Multiple Edit...") );
+		data->MI_assign    = hbtk_menu_add_menuitem(menu, _("Create assignment..."));
 		data->MI_template  = hbtk_menu_add_menuitem(menu, _("Create template...") );
 		data->MI_delete    = menuitem = hbtk_menu_add_menuitem(menu, _("_Delete...") );
 		gtk_widget_add_accelerator (menuitem, "activate", accel_group, GDK_KEY_Delete, (GdkModifierType)0, GTK_ACCEL_VISIBLE);
@@ -2327,7 +2509,6 @@ struct register_panel_data *data;
 struct WinGeometry *wg;
 GtkWidget *window, *mainbox, *intbox, *menubar, *table, *sw, *bar;
 GtkWidget *treeview, *label, *widget, *image;
-//GtkWidget *menu, *menu_items;
 
 	DB( g_print("\n[register] create_register_panel_window\n") );
 
@@ -2616,6 +2797,7 @@ GtkWidget *treeview, *label, *widget, *image;
 	g_signal_connect (data->MI_exportqif , "activate", G_CALLBACK (register_panel_action_exportqif), (gpointer)data);
 	g_signal_connect (data->MI_exportcsv , "activate", G_CALLBACK (register_panel_action_exportcsv), (gpointer)data);
 	g_signal_connect (data->MI_exportpdf , "activate", G_CALLBACK (register_panel_action_exportpdf), (gpointer)data);
+	g_signal_connect (data->MI_print     , "activate", G_CALLBACK (register_panel_action_exportpdf), (gpointer)data);
 	g_signal_connect (data->MI_close     , "activate", G_CALLBACK (register_panel_action_close), (gpointer)data);
 
 	g_signal_connect (data->MI_copy      , "activate", G_CALLBACK (register_panel_action_edit_copy), (gpointer)data);
@@ -2666,22 +2848,14 @@ GtkWidget *treeview, *label, *widget, *image;
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), "changed", G_CALLBACK (register_panel_selection), NULL);
 	g_signal_connect (GTK_TREE_VIEW(treeview), "row-activated", G_CALLBACK (register_panel_onRowActivated), GINT_TO_POINTER(2));
 
-//todo: test context menu
-	/*
-	menu = gtk_menu_new();
-	menu_items = gtk_ui_manager_get_widget (ui, "/MenuBar/TxnMenu/Add");
-
-	menu_items = gtk_menu_item_new_with_label ("test");
-	gtk_widget_show(menu_items);
-	gtk_menu_shell_append (GTK_MENU (menu), menu_items);
-
+	GtkWidget *popmenu = register_panel_popmenu_create(data);
+	
 	//todo: debug test
 	g_signal_connect (treeview, "button-press-event", G_CALLBACK (listview_context_cb),
 		// todo: here is not a GtkMenu but GtkImageMenuItem...
-		menu
+		popmenu
 		//gtk_ui_manager_get_widget (ui, "/MenuBar")
 	);
-	*/
 
 	//setup, init and show window
 	wg = &PREFS->acc_wg;
