@@ -40,6 +40,16 @@ enum
 	MAX_ACTION_ACCOUNT
 };
 
+
+enum {
+	FLG_REG_TITLE     	= 1 << 0,	//1
+	FLG_REG_SENSITIVE 	= 1 << 1,	//2
+	FLG_REG_BALANCE   	= 1 << 2,	//4
+	FLG_REG_VISUAL    	= 1 << 3,	//8
+	FLG_REG_REFRESHALL	= 1 << 4	//16
+};
+
+
 enum {
 	HID_RANGE,
 	HID_TYPE,
@@ -57,11 +67,11 @@ struct register_panel_data
 	GtkWidget	*NB_txn_daygap;
 	
 	GtkWidget	*ME_menuacc, *ME_menuedit, *ME_menutxn, *ME_menutools, *ME_menustatus;
-	GtkWidget	*MI_exportqif, *MI_exportcsv, *MI_exportpdf, *MI_close;
+	GtkWidget	*MI_exportqif, *MI_exportcsv, *MI_exportpdf, *MI_print, *MI_close;
 	GtkWidget	*MI_copy, *MI_pasten, *MI_pastet;
 	GtkWidget	*MI_add, *MI_herit, *MI_edit;
 	GtkWidget	*MI_statnone, *MI_statclear, *MI_statrecon;
-	GtkWidget	*MI_multiedit, *MI_template, *MI_delete;
+	GtkWidget	*MI_multiedit, *MI_assign, *MI_template, *MI_delete;
 	GtkWidget	*MI_find;
 	GtkWidget	*MI_markdup, *MI_chkintxfer, *MI_autoassign, *MI_autopayee, *MI_filter, *MI_conveuro;
 
@@ -90,6 +100,13 @@ struct register_panel_data
 
 	GtkWidget	*LV_ope;
 
+	GtkWidget	*ME_popmenu, *ME_popmenustatus;
+	GtkWidget	*MI_popadd, *MI_popherit, *MI_popedit;
+	GtkWidget	*MI_popstatnone, *MI_popstatclear, *MI_popstatrecon;
+	GtkWidget	*MI_popmultiedit, *MI_poptemplate, *MI_popassign, *MI_popdelete;
+	GtkWidget	*MI_popviewsplit, *MI_poptxnup, *MI_poptxndown;
+	
+
 	gint	busy;
 	gchar	*wintitle;
 
