@@ -251,7 +251,7 @@ GtkWidget *widget = GLOBALS->mainwindow;
 		ui_mainwindow_clear(widget, GINT_TO_POINTER(TRUE)); // GPOINTER_TO_INT(
 		ui_mainwindow_update(widget, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 
-		ui_start_assistant();
+		ui_newfile_assitant_new();
 	}
 }
 
@@ -288,7 +288,7 @@ GtkWidget *widget = GLOBALS->mainwindow;
 	{
 		//clear all, and init GLOBALS->xhb_filepath to default
 		ui_mainwindow_clear(widget, GINT_TO_POINTER(TRUE));
-		ui_mainwindow_update(widget, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_REFRESHALL));
+		ui_mainwindow_update(widget, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 	}
 
 }
@@ -348,7 +348,7 @@ gchar *secondtext;
 static void ui_mainwindow_action_defcurrency(void)
 {
 	ui_cur_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE+UF_REFRESHALL));
 }
 
 
@@ -361,13 +361,13 @@ static void ui_mainwindow_action_defaccount(void)
 	account_compute_balances ();
 	ui_hub_account_populate(GLOBALS->mainwindow, NULL);
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defpayee(void)
 {
 	ui_pay_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defcategory(void)
@@ -375,7 +375,7 @@ static void ui_mainwindow_action_defcategory(void)
 	ui_cat_manage_dialog();
 	//todo:why refresh upcoming here??
 	//ui_mainwindow_populate_upcoming(GLOBALS->mainwindow, NULL);
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE+UF_REFRESHALL));
 }
 
 
@@ -395,7 +395,7 @@ GtkTreeModel *model;
 
 	ui_hub_scheduled_populate(GLOBALS->mainwindow, NULL);
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 
@@ -408,13 +408,13 @@ static void ui_mainwindow_action_defarchive(void)
 static void ui_mainwindow_action_defbudget(void)
 {
 	ui_bud_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defbudgettable(void)
 {
 	ui_bud_tabview_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defassign(void)
@@ -422,7 +422,7 @@ static void ui_mainwindow_action_defassign(void)
 
 	ui_asg_manage_dialog();
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 
@@ -431,7 +431,7 @@ static void ui_mainwindow_action_deftag(void)
 
 	ui_tag_manage_dialog();
 
-	//ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	//ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 }
 
 
@@ -641,86 +641,101 @@ gchar *link;
 
 //todo: move this to a ui-assist-welcome.c
 
-static void ui_mainwindow_action_help_welcome1 (GtkButton *button, gpointer user_data)
+
+
+static void ui_mainwindow_action_help_welcome_cb (GtkWidget *widget, gpointer user_data)
 {
-	gtk_dialog_response (GTK_DIALOG(user_data), 1);
+GtkWidget *dialog;
+gint response = GPOINTER_TO_INT(user_data);
+
+	dialog = gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW);
+	if( GTK_IS_DIALOG(dialog) )
+		gtk_dialog_response (GTK_DIALOG(dialog), response);
 }
 
-static void ui_mainwindow_action_help_welcome2 (GtkButton *button, gpointer user_data)
-{
-	gtk_dialog_response (GTK_DIALOG(user_data), 2);
-}
 
-static void ui_mainwindow_action_help_welcome3 (GtkButton *button, gpointer user_data)
-{
-	gtk_dialog_response (GTK_DIALOG(user_data), 3);
-}
-
-static void ui_mainwindow_action_help_welcome4 (GtkButton *button, gpointer user_data)
-{
-	gtk_dialog_response (GTK_DIALOG(user_data), 4);
-}
-
-static void ui_mainwindow_action_help_welcome5 (GtkButton *button, gpointer user_data)
-{
-	gtk_dialog_response (GTK_DIALOG(user_data), 5);
-}
-
-void ui_mainwindow_action_help_welcome(void)
+gint ui_mainwindow_action_help_welcome(void)
 {
 GtkWidget *dialog, *content_area;
-GtkWidget *mainvbox, *widget, *label;
+GtkWidget *mainvbox, *table, *widget, *label, *check;
+gchar *pathfilename;
 
 	dialog = gtk_dialog_new_with_buttons (_("Welcome to HomeBank"),
 			GTK_WINDOW(GLOBALS->mainwindow),
 			0,
 			_("_Close"),
-			GTK_RESPONSE_ACCEPT,
+			//_("_Exit"),
+			GTK_RESPONSE_CLOSE,
 			NULL);
 
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
-	
-	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_box_pack_start (GTK_BOX (content_area), mainvbox, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
 
+	table = gtk_grid_new ();
+	//gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(table), SPACING_LARGE);
+	gtk_box_pack_start (GTK_BOX (content_area), table, FALSE, FALSE, 0);
+
+	//get our icon
+	pathfilename = g_build_filename(homebank_app_get_images_dir(), "homebank-icon.svg", NULL);
+	if (g_file_test (pathfilename, G_FILE_TEST_EXISTS) == TRUE)
+		widget = gtk_image_new_from_file((const gchar *)pathfilename);
+	else
+		widget = gtk_image_new_from_icon_name ("homebank", GTK_ICON_SIZE_DIALOG);
+	g_free(pathfilename);
+	gtk_grid_attach (GTK_GRID (table), widget, 0, 0, 1, 2);
+	
 	label = make_label (_("HomeBank"), 0, 0);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, PANGO_ATTR_SCALE,  PANGO_SCALE_XX_LARGE, -1);
+	gtk_grid_attach (GTK_GRID (table), label, 1, 0, 1, 1);
 
 	label = make_label (_("Free, easy, personal accounting for everyone"), 0, 0);
-	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL, -1);
+	gtk_grid_attach (GTK_GRID (table), label, 1, 1, 1, 1);
 
+	
 	widget = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (content_area), widget, FALSE, FALSE, 0);
 
+	
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_MEDIUM);
-	gtk_box_pack_start (GTK_BOX (content_area), mainvbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (content_area), mainvbox, FALSE, FALSE, 0);
+	gtk_widget_set_halign (mainvbox, GTK_ALIGN_CENTER);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_LARGE);
 
-	label = make_label (_("What do you want to do:"), 0, 0);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+	//label = make_label (_("What do you want to do:"), 0, 0);
+	//gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	//gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
-	widget = gtk_button_new_with_mnemonic(_("Read HomeBank _Manual"));
+	widget = gtk_button_new_with_mnemonic(_("Open _last opened file"));
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
-	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome1), dialog);
-	
-	widget = gtk_button_new_with_mnemonic(_("Configure _preferences"));
-	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
-	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome2), dialog);
-	
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_OPENLAST));
+
 	widget = gtk_button_new_with_mnemonic(_("Create a _new file"));
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
-	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome3), dialog);
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_CREATENEW));
 
 	widget = gtk_button_new_with_mnemonic(_("_Open an existing file"));
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
-	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome4), dialog);
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_OPENEXISTING));
 
 	widget = gtk_button_new_with_mnemonic(_("Open the _example file"));
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
-	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome5), dialog);
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_OPENSAMPLE));
+
+	widget = gtk_button_new_with_mnemonic(_("Read HomeBank _Manual"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_READMANUAL));
+	
+	widget = gtk_button_new_with_mnemonic(_("Configure _preferences"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
+	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome_cb), GINT_TO_POINTER(HB_WELCOME_CONFIGPREF));
+
+	check = gtk_check_button_new_with_mnemonic (_("Show this window next time"));
+	gtk_box_pack_end (GTK_BOX (mainvbox), check, FALSE, FALSE, SPACING_SMALL);
+
+	//init
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check), PREFS->showwelcome);
 
 	//connect all our signals
 	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
@@ -730,30 +745,39 @@ GtkWidget *mainvbox, *widget, *label;
 	//wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
+	PREFS->showwelcome = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(check));
+
 	// cleanup and destroy
 	gtk_widget_destroy (dialog);
 
 	// do appropriate action
 	switch(result)
 	{
-		case 1:
+		case HB_WELCOME_OPENLAST:
+			{
+			gchar *rawfilepath = homebank_lastopenedfiles_load();
+			ui_mainwindow_open_check(GLOBALS->mainwindow, rawfilepath);			
+			}
+			break;
+		case HB_WELCOME_READMANUAL:
 			ui_mainwindow_action_help();
 			break;
-		case 2:
+		case HB_WELCOME_CONFIGPREF:
 			ui_mainwindow_action_preferences();
 			break;
-		case 3:
+		case HB_WELCOME_CREATENEW:
 			ui_mainwindow_action_new();
 			break;
-		case 4:
+		case HB_WELCOME_OPENEXISTING:
 			ui_mainwindow_action_open();
 			break;
-		case 5:
+		case HB_WELCOME_OPENSAMPLE:
 			hbfile_change_filepath(g_build_filename(homebank_app_get_datas_dir(), "example.xhb", NULL));
 			ui_mainwindow_open_internal(GLOBALS->mainwindow, NULL);
 			break;
 	}
 
+	return result;
 }
 
 
@@ -924,12 +948,12 @@ Transaction *ope;
 	if(count > 0)
 	{
 		GLOBALS->changes_count += count;
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_REFRESHALL));
+		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE+UF_REFRESHALL));
 	}
 }
 
 
-gboolean ui_mainwindow_open_backup_check_confirm(gchar *filepath)
+static gboolean ui_mainwindow_open_backup_check_confirm(gchar *filepath)
 {
 gboolean retval = FALSE;
 gchar *basename, *secondtext;
@@ -937,11 +961,11 @@ gboolean result;
 
 	basename = g_path_get_basename(filepath);
 	secondtext = g_strdup_printf (
-	_("Your are about to open the backup file '%s'.\n\nAre you sure you want to do this ?"), basename);		
+	_("You are about to open the backup file '%s'.\n\nAre you sure you want to do this?"), basename);		
 
 	result = ui_dialog_msg_confirm_alert(
 		GTK_WINDOW(GLOBALS->mainwindow),
-		_("Open the backup file ?"),
+		_("Open the backup file?"),
 		secondtext,
 		_("_Open backup")
 	);	
@@ -956,9 +980,51 @@ gboolean result;
 }
 
 
-/*
-**
-*/
+void ui_mainwindow_open_check(GtkWidget *widget, gchar *filepath)
+{
+//struct hbfile_data *data;
+gboolean doopen = TRUE;
+
+	if( filepath == NULL )
+		return;
+
+	DB( g_print("\n[ui-mainwindow] open check\n") );
+
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	
+	DB( g_print(" path='%s'\n", filepath) );
+
+	if (g_file_test (filepath, G_FILE_TEST_EXISTS) == TRUE)
+	{
+		//#1710955 test for backup open
+		if( hbfile_file_isbackup(filepath) )
+		{
+			if( ui_mainwindow_open_backup_check_confirm(filepath) == TRUE )
+			{
+				GLOBALS->hbfile_is_bak = TRUE;
+				doopen = TRUE;
+			}
+			else
+			{
+				doopen = FALSE;
+			}
+		}
+	}
+	else
+	{
+		g_warning (_("Unable to open '%s', the file does not exist.\n"), filepath);
+	}
+
+	if(doopen)
+	{
+		hbfile_change_filepath(g_strdup(filepath));
+		ui_mainwindow_open_internal(widget, NULL);
+	}	
+
+	g_free(filepath);
+}
+
+
 void ui_mainwindow_open(GtkWidget *widget, gpointer user_data)
 {
 //struct hbfile_data *data;
@@ -978,22 +1044,7 @@ gchar *filename = NULL;
 	{
 		if( ui_file_chooser_xhb(GTK_FILE_CHOOSER_ACTION_OPEN, &filename, bakmode) == TRUE )
 		{
-			//#1710955 test for backup open
-			if( hbfile_file_isbackup(filename) )
-			{
-				if( ui_mainwindow_open_backup_check_confirm(filename) == TRUE )
-				{
-					GLOBALS->hbfile_is_bak = TRUE;
-				}
-				else
-				{
-					g_free(filename);
-					return;
-				}
-			}			
-
-			hbfile_change_filepath(filename);
-			ui_mainwindow_open_internal(widget, NULL);
+			ui_mainwindow_open_check(widget, filename);
 		}
 	}
 }
@@ -1175,6 +1226,13 @@ gint flags;
 
 	flags = GPOINTER_TO_INT(user_data);
 
+	/* changes */
+#if MYDEBUG == 1
+	gchar *chgtxt = g_strdup_printf("%d", GLOBALS->changes_count);
+	gtk_label_set_label(GTK_LABEL(data->dbgchange), chgtxt);
+	g_free(chgtxt);
+#endif	
+
 	/* set window title */
 	if(flags & UF_TITLE)
 	{
@@ -1184,21 +1242,10 @@ gint flags;
 		DB( g_print(" 1: wintitle %p\n", data->wintitle) );
 
 		basename = g_path_get_basename(GLOBALS->xhb_filepath);
-
-		DB( g_print(" global changes: %d\n", GLOBALS->changes_count) );
-
 		g_free(data->wintitle);
-
 		changed = (GLOBALS->changes_count > 0) ? "*" : "";
-
-#if MYDEBUG == 1
-		data->wintitle = g_strdup_printf("%s%s (%d)- %s - " PROGNAME, changed, basename, GLOBALS->changes_count, GLOBALS->owner);
-#else
 		data->wintitle = g_strdup_printf("%s%s - %s - " PROGNAME, changed, basename, GLOBALS->owner);
-#endif
-		
 	    gtk_window_set_title (GTK_WINDOW (gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), data->wintitle);
-
 		g_free(basename);
 	}
 
@@ -1272,19 +1319,24 @@ gint flags;
 		DB( g_print(" has acc ?\n") );
 		sensitive = da_acc_length() > 0 ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_close, sensitive);
+		gtk_widget_set_sensitive(data->MI_exportqif, sensitive);
+		gtk_widget_set_sensitive(data->MI_anonymise, sensitive);
 		gtk_widget_set_sensitive(data->MI_mantpl, sensitive);
 		gtk_widget_set_sensitive(data->MI_txnadd, sensitive);
 		gtk_widget_set_sensitive(data->MI_txnshow, sensitive);
+		gtk_widget_set_sensitive(data->MI_txnshowall, sensitive);
 		gtk_widget_set_sensitive(data->MI_repstat, sensitive);
 		gtk_widget_set_sensitive(data->MI_reptime, sensitive);
+		gtk_widget_set_sensitive(data->MI_repbal,  sensitive);
 		gtk_widget_set_sensitive(data->MI_repbudg, sensitive);
 		gtk_widget_set_sensitive(data->MI_repvehi, sensitive);
 
-		gtk_widget_set_sensitive(data->BT_mantpl, sensitive);
+		gtk_widget_set_sensitive(data->BT_mantpl,  sensitive);
 		gtk_widget_set_sensitive(data->BT_txnshow, sensitive);
-		gtk_widget_set_sensitive(data->BT_txnadd, sensitive);
+		gtk_widget_set_sensitive(data->BT_txnadd,  sensitive);
 		gtk_widget_set_sensitive(data->BT_repstat, sensitive);
 		gtk_widget_set_sensitive(data->BT_reptime, sensitive);
+		gtk_widget_set_sensitive(data->BT_repbal,  sensitive);
 		gtk_widget_set_sensitive(data->BT_repbudg, sensitive);
 		gtk_widget_set_sensitive(data->BT_repvehi, sensitive);
 		
@@ -1293,11 +1345,14 @@ gint flags;
 		sensitive = da_cat_length() > 1 ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_manbud, sensitive);
 		gtk_widget_set_sensitive(data->MI_manbudtable, sensitive);
+		gtk_widget_set_sensitive(data->BT_manbud, sensitive);
 
+		
 		//#1501129 no need to disable, P & C can be created from assign dialog
 		//sensitive = ((da_cat_length() > 1) || (da_pay_length() > 1)) ? TRUE : FALSE;
 		//gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ManageMenu/Assign"), sensitive);
 		gtk_widget_set_sensitive(data->MI_manasg, sensitive);
+		gtk_widget_set_sensitive(data->BT_manasg, sensitive);
 
 	// empty archive list: disable scheduled check
 		DB( g_print(" has archive ?\n") );
@@ -1324,56 +1379,27 @@ gint flags;
 			gtk_toolbar_set_style(GTK_TOOLBAR(data->toolbar), PREFS->toolbar_style-1);
 
 		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_acc), PREFS->grid_lines);
-		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
-
 		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_upc), PREFS->grid_lines);
-		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
+		//TODO: should add txn listview here as well
+		//gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
+		//gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
 
 		DB( g_print(" - show toolbar=%d\n", PREFS->wal_toolbar) );
-		if(PREFS->wal_toolbar)
-			gtk_widget_show(GTK_WIDGET(data->toolbar));
-		else
-			gtk_widget_hide(GTK_WIDGET(data->toolbar));
-
+		hb_widget_visible(data->toolbar, PREFS->wal_toolbar); 
 
 		DB( g_print(" - show top_spending=%d\n", PREFS->wal_spending) );
+		hb_widget_visible(data->GR_top, PREFS->wal_spending); 
 
+		//TODO: why this ? to redraw ?
 		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_wal);
-
-		if(PREFS->wal_spending)
-			gtk_widget_show(GTK_WIDGET(data->GR_top));
-		else
-			gtk_widget_hide(GTK_WIDGET(data->GR_top));
-
-
 		
 		DB( g_print(" - show upcoming=%d\n", PREFS->wal_upcoming) );
-		if(PREFS->wal_upcoming)
-			gtk_widget_show(GTK_WIDGET(data->GR_upc));
-		else
-			gtk_widget_hide(GTK_WIDGET(data->GR_upc));
+		hb_widget_visible(data->GR_upc, PREFS->wal_upcoming); 
 
 		DB( g_print(" minor %d\n", PREFS->euro_active) );
 		hb_widget_visible(data->MI_eurominor, PREFS->euro_active);
 	}
 
-	/* update balances */
-	if(flags & UF_BALANCE)
-	{
-
-		DB( g_print(" 4: balances\n") );
-
-		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
-
-		//minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
-
-		/*
-		hb-label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->bank, minor);
-		hb-label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->today, minor);
-		hb-label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->future, minor);
-		*/
-	}
-
 	if(flags & UF_REFRESHALL)
 	{
 		DB( g_print(" 16: refreshall\n") );
@@ -1388,7 +1414,6 @@ gint flags;
 }
 
 
-
 static void
   ui_mainwindow_onRowActivated (GtkTreeView        *treeview,
                        GtkTreePath        *path,
@@ -1876,12 +1901,12 @@ GtkWidget *toolbar, *button, *menu;
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
-	data->BT_manacc  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ACCOUNT , _("Account"), _("Configure the accounts"));
-	data->BT_manpay  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_PAYEE   , _("Payee"), _("Configure the payees"));
-	data->BT_mancat  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_CATEGORY, _("Category"), _("Configure the categories"));
-	data->BT_mantpl  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ARCHIVE , _("Archive"), _("Configure the scheduled/template transactions"));
-	data->BT_manbud  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_BUDGET  , _("Budget"), _("Configure the budget"));
-	data->BT_manasg  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ASSIGN  , _("Assignment"), _("Configure the automatic assignments"));
+	data->BT_manacc  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ACCOUNT , _("Account"), _("Manage the accounts"));
+	data->BT_manpay  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_PAYEE   , _("Payee"), _("Manage the payees"));
+	data->BT_mancat  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_CATEGORY, _("Category"), _("Manage the categories"));
+	data->BT_mantpl  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ARCHIVE , _("Scheduled/Template"), _("Manage the scheduled/template transactions"));
+	data->BT_manbud  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_BUDGET  , _("Budget"), _("Manage the budget"));
+	data->BT_manasg  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_ASSIGN  , _("Assignment"), _("Manage the automatic assignments"));
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
@@ -1939,13 +1964,13 @@ GtkWidget *window;
 	//menu and toolbar
 	data->recent_manager = gtk_recent_manager_get_default ();
 
-	menubar = ui_mainwindow_menubar_create(data);
-#if HB_UNSTABLE_SHOW == TRUE
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (mainvbox), box, FALSE, FALSE, 0);
 
+	menubar = ui_mainwindow_menubar_create(data);
 	gtk_box_pack_start (GTK_BOX (box), menubar, TRUE, TRUE, 0);
 
+#if HB_UNSTABLE_SHOW == TRUE
 	menubar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(menubar)), GTK_STYLE_CLASS_MENUBAR);
 	gtk_box_pack_start (GTK_BOX (box), menubar, FALSE, FALSE, 0);
@@ -1964,14 +1989,19 @@ GtkWidget *window;
 	    "- use A COPY of your files\n"
 	    "- BUGs or CRASH can still occur"
 		);
-#else	
-	gtk_box_pack_start (GTK_BOX (mainvbox), menubar, FALSE, FALSE, 0);
 #endif
-	
+
+#if MYDEBUG == 1
+	widget = make_label(NULL, 1.0, 0.5);
+	gtk_widget_set_margin_end(widget, 12);
+	data->dbgchange = widget;
+	gtk_box_pack_end (GTK_BOX (box), widget, FALSE, FALSE, 0);
+#endif
+
+
 	toolbar = ui_mainwindow_toolbar_create(data);
 	data->toolbar = toolbar;
 	gtk_box_pack_start (GTK_BOX (mainvbox), toolbar, FALSE, FALSE, 0);
-
 	
 	/* Add the main area */
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
