@@ -479,8 +479,10 @@ void filter_preset_status_set(Filter *flt, gint status)
 	//flt->forceadd = TRUE;
 	//flt->forcechg = TRUE;
 
-	//keep widget active_id
-	flt->rawstatus = status;
+	//#1860356 keep widget active_id
+	//#1873324 register status quick filter do not reset
+	//note: status revert to UNRECONCILED here is normal if PREFS->hidereconciled=TRUE
+	//flt->rawstatus = status;
 	
 	switch( status )
 	{
@@ -719,7 +721,9 @@ gchar *tags;
 	if(flags & FLT_QSEARCH_AMOUNT)
 	{
 	gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
-	
+
+		DB( g_print(" needle='%s' txnamt='%s'\n", needle, formatd_buf) );
+		
 		hb_strfnum(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, FALSE);
 		retval |= hb_string_utf8_strstr(formatd_buf, needle, FALSE);
 	}
