@@ -103,8 +103,8 @@ struct _filter
 	guint32		mindate, maxdate;
 	gint		range;
 
-	gint		rawtype, type;
-	gint		rawstatus, status;
+	//gint		rawtype, rawstatus;
+	gint		type, status;
 
 	//gboolean	
 	gboolean	paymode[NUM_PAYMODE_MAX];
