@@ -252,6 +252,7 @@ gdouble monval;
 }
 
 
+// used only in gtk_chart.c
 void hb_strfmon_int(gchar *outstr, gint outlen, gdouble value, guint32 kcur, gboolean minor)
 {
 gchar formatd_buf[outlen];
@@ -282,7 +283,6 @@ gdouble monval;
 
 void hb_strfnum(gchar *outstr, gint outlen, gdouble value, guint32 kcur, gboolean minor)
 {
-gchar formatd_buf[outlen];
 Currency *cur;
 gdouble monval;
 
@@ -292,19 +292,17 @@ gdouble monval;
 		if(cur != NULL)
 		{
 			monval = hb_amount_round(value, cur->frac_digits);
-			g_ascii_formatd(formatd_buf, outlen, "%.2f", monval);
-			hb_str_formatd(outstr, outlen, formatd_buf, cur, TRUE);
+			//#1868185 print raw number, not with monetary
+			g_ascii_formatd(outstr, outlen, "%.2f", monval);
 		}
 	}
 	else
 	{
 		cur = &PREFS->minor_cur;
 		monval = hb_amount_to_euro(value);
-		g_ascii_formatd(formatd_buf, outlen, "%.2f", monval);
-		hb_str_formatd(outstr, outlen, formatd_buf, cur, TRUE);
+		//#1868185 print raw number, not with monetary
+		g_ascii_formatd(outstr, outlen, "%.2f", monval);
 	}
-
-	
 }
 
 
