@@ -45,177 +45,6 @@ extern struct Preferences *PREFS;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-static void homebank_pref_init_monetary(void)
-{
-
-	DB( g_print("\n[system] get currency code\n") );
-	
-#ifdef G_OS_UNIX
-	struct lconv *lc = localeconv();
-
-	g_stpcpy (PREFS->IntCurrSymbol, lc->int_curr_symbol);
-	g_strstrip(PREFS->IntCurrSymbol);
-
-	DB( g_print("- stored '%s' from linux system\n", PREFS->IntCurrSymbol) );
-#else
-
-	#ifdef G_OS_WIN32
-    #define BUFFER_SIZE 512
-    char buffer[BUFFER_SIZE];
-    //LPWSTR wcBuffer = buffer;
-    LPSTR wcBuffer = buffer;
-    int iResult;
-
-	//https://msdn.microsoft.com/en-us/library/windows/desktop/dd464799%28v=vs.85%29.aspx
-
-	//LOCALE_SINTLSYMBOL
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SINTLSYMBOL, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_SINTLSYMBOL='%s'\n", buffer) );
-	 	g_stpcpy (PREFS->IntCurrSymbol, buffer);
-		g_strstrip(PREFS->IntCurrSymbol);
-
-		DB( g_print("- stored '%s' from windows system\n", PREFS->IntCurrSymbol) );
-    }
-	#else
-
- 	g_stpcpy (PREFS->IntCurrSymbol, "USD");
-
-	DB( g_print("- stored '%s' as default\n", PREFS->IntCurrSymbol) );
-	
-	#endif
-	
-#endif
-	
-
-}
-
-
-/*
-static void homebank_pref_init_monetary(void)
-{
-	DB( g_print("\n[preferences] monetary\n") );
-
-
-#ifdef G_OS_UNIX
-
-struct lconv *lc = localeconv();
-
-	DB( g_print("\n[preferences] monetary unix\n") );
-
-	DB( g_print("int_curr_symbol '%s'\n", lc->int_curr_symbol) );
-	
-	DB( g_print("mon_decimal_point is utf8: %d\n", g_utf8_validate(lc->mon_decimal_point, -1, NULL)) );
-	DB( g_print("mon_decimal_point '%s'\n", lc->mon_decimal_point) );
-	DB( g_print("mon_decimal_point %x %x %x %x\n", lc->mon_decimal_point[0], lc->mon_decimal_point[1], lc->mon_decimal_point[2], lc->mon_decimal_point[3]) );
-
-	DB( g_print("mon_thousands_sep is utf8: %d\n", g_utf8_validate(lc->mon_thousands_sep, -1, NULL)) );
-	DB( g_print("mon_thousands_sep '%s'\n", lc->mon_thousands_sep) );
-	DB( g_print("mon_thousands_sep %x %x %x %x\n", lc->mon_thousands_sep[0], lc->mon_thousands_sep[1], lc->mon_thousands_sep[2], lc->mon_thousands_sep[3]) );
-
-
-	DB( g_print("frac_digits '%d'\n", (gint)lc->frac_digits) );
-
-	DB( g_print("currency_symbol '%s'\n", lc->currency_symbol) );
-
-	DB( g_print("p_cs_precedes '%d'\n", lc->p_cs_precedes) );
-
-	DB( g_print("n_cs_precedes '%d'\n", lc->n_cs_precedes) );
-
-	//PREFS->base_cur.iso_code = g_strdup(g_strstrip(lc->int_curr_symbol));
-
-	if( lc->p_cs_precedes || lc->n_cs_precedes )
-	{
-		PREFS->base_cur.symbol = g_strdup(lc->currency_symbol);
-		PREFS->base_cur.sym_prefix = TRUE;
-		DB( g_print("locale mon cs is a prefix\n") );
-	}
-	else
-	{
-		PREFS->base_cur.symbol = g_strdup(lc->currency_symbol);
-		PREFS->base_cur.sym_prefix = FALSE;
-	}
-
-	PREFS->base_cur.decimal_char  = g_strdup(lc->mon_decimal_point);
-
-	PREFS->base_cur.grouping_char = g_strdup(lc->mon_thousands_sep);
-
-	//todo:fix
-	//PREFS->base_cur.grouping_char = g_locale_to_utf8(lc->mon_thousands_sep, -1, NULL, NULL, NULL);
-	//PREFS->base_cur.grouping_char = g_convert (lc->mon_thousands_sep, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
-
-	DB( g_print(" -> grouping_char: '%s'\n", PREFS->base_cur.grouping_char) );
-
-	PREFS->base_cur.frac_digits   = lc->frac_digits;
-
-	//fix 378992/421228
-	if( PREFS->base_cur.frac_digits > MAX_FRAC_DIGIT )
-	{
-		PREFS->base_cur.frac_digits = 2;
-		g_free(PREFS->base_cur.decimal_char);
-		PREFS->base_cur.decimal_char  = g_strdup(".");
-	}
-
-#else
-	#ifdef G_OS_WIN32
-
-    #define BUFFER_SIZE 512
-    char buffer[BUFFER_SIZE];
-    //LPWSTR wcBuffer = buffer;
-    LPSTR wcBuffer = buffer;
-    int iResult;
-    gsize toto;
-
-	//https://msdn.microsoft.com/en-us/library/windows/desktop/dd464799%28v=vs.85%29.aspx
-
-	//LOCALE_SINTLSYMBOL
-
-	
-    //see g_locale_to_utf8 here
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SCURRENCY, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_SCURRENCY='%s'\n", buffer) );
-        PREFS->base_cur.symbol = g_locale_to_utf8(buffer, -1, NULL, &toto, NULL);
-    }
-
-	// LOCALE_ICURRENCY
-	//PREFS->base_cur.sym_prefix =
-	
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_SDECIMAL='%s'\n", buffer) );
-        PREFS->base_cur.decimal_char  = g_locale_to_utf8(buffer, -1, NULL, &toto, NULL);
-    }
-
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_STHOUSAND, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_STHOUSAND='%s'\n", buffer) );
-        PREFS->base_cur.grouping_char = g_locale_to_utf8(buffer, -1, NULL, &toto, NULL);
-    }
-
-	// LOCALE_ICURRDIGITS
- 	PREFS->base_cur.frac_digits   = 2;
-
-	#else
-
-	PREFS->base_cur.iso_code      = g_strdup("USD");
-	PREFS->base_cur.symbol        = NULL; //g_strdup("");
-	PREFS->base_cur.sym_prefix    = FALSE;
-	PREFS->base_cur.decimal_char  = g_strdup(".");
-	PREFS->base_cur.grouping_char = NULL; //g_strdup("");
-	PREFS->base_cur.frac_digits   = 2;
-
-	#endif
-#endif
-
-}
-*/
-
-
 
 static void homebank_pref_init_wingeometry(struct WinGeometry *wg, gint l, gint t, gint w, gint h)
 {
@@ -318,6 +147,7 @@ gint i;
 	//PREFS->path_navigator = g_strdup(DEFAULT_PATH_NAVIGATOR);
 
 	PREFS->showsplash = TRUE;
+	PREFS->showwelcome = TRUE;
 	PREFS->loadlast = TRUE;
 	PREFS->appendscheduled = FALSE;
 	PREFS->do_update_currency = FALSE;
@@ -357,7 +187,7 @@ gint i;
 
 	homebank_pref_init_wingeometry(&PREFS->txn_wg, 0, 0, -1, -1);
 
-	homebank_pref_init_monetary();
+	currency_get_system_iso();
 
 	PREFS->wal_toolbar = TRUE;
 	PREFS->wal_spending = TRUE;
@@ -695,6 +525,10 @@ GError *error = NULL;
 					}
 					else
 						homebank_pref_get_short(keyfile, group, "GridLines", &PREFS->grid_lines);
+
+					//we disable showwelcome for old users
+					if( version < 540 )
+						PREFS->showwelcome = FALSE;
 				}
 
 				DB( g_print(" - color exp: %s\n", PREFS->color_exp) );
@@ -704,10 +538,16 @@ GError *error = NULL;
 
 				homebank_pref_get_string(keyfile, group, "WalletPath", &PREFS->path_hbfile);
 				homebank_pref_get_string(keyfile, group, "BackupPath", &PREFS->path_hbbak);
+				//#1870433 default backup path folder not initialized with wallet folder			
+				if( version < 530 )
+				{
+					homebank_pref_get_string(keyfile, group, "WalletPath", &PREFS->path_hbbak);
+				}
 				homebank_pref_get_string(keyfile, group, "ImportPath", &PREFS->path_import);
 				homebank_pref_get_string(keyfile, group, "ExportPath", &PREFS->path_export);
 
 				homebank_pref_get_boolean(keyfile, group, "ShowSplash", &PREFS->showsplash);
+				homebank_pref_get_boolean(keyfile, group, "ShowWelcome", &PREFS->showwelcome);
 				homebank_pref_get_boolean(keyfile, group, "LoadLast", &PREFS->loadlast);
 				homebank_pref_get_boolean(keyfile, group, "AppendScheduled", &PREFS->appendscheduled);
 				homebank_pref_get_boolean(keyfile, group, "UpdateCurrency", &PREFS->do_update_currency);	
@@ -1079,6 +919,7 @@ GError *error = NULL;
 		g_key_file_set_integer (keyfile, group, "BakMaxNumCopies", PREFS->bak_max_num_copies);
 
 		g_key_file_set_boolean (keyfile, group, "ShowSplash", PREFS->showsplash);
+		g_key_file_set_boolean (keyfile, group, "ShowWelcome", PREFS->showwelcome);
 		g_key_file_set_boolean (keyfile, group, "LoadLast", PREFS->loadlast);
 		g_key_file_set_boolean (keyfile, group, "AppendScheduled", PREFS->appendscheduled);
 		g_key_file_set_boolean (keyfile, group, "UpdateCurrency", PREFS->do_update_currency);
