@@ -243,6 +243,11 @@ guint32 *tags_clone(guint32 *tags)
 guint32 *newtags = NULL;
 guint count;
 
+	DB( g_print("\n[tags] clone\n") );
+
+	if( tags == NULL )
+		return NULL;
+
 	count = tags_count(tags);
 	if(count > 0)
 	{
@@ -258,6 +263,10 @@ static gboolean
 tags_key_exists(guint32 *tags, guint32 key)
 {
 guint count = 0;
+
+	if( tags == NULL )
+		return FALSE;
+
 	while(*tags != 0 && count < 32)
 	{
 		if( *tags == key )
@@ -269,6 +278,74 @@ guint count = 0;
 }
 
 
+static void
+tags_deduplicate(guint32 *tags)
+{
+guint32 *tmp, *s, *d;
+guint count = 0;
+	
+	DB( g_print("\n[tags] deduplicate\n") );
+
+	if( tags == NULL )
+		return;
+	
+	tmp = s = tags_clone(tags);
+	d = tags;
+	*d = 0;
+	while(*s != 0 && count < 32)
+	{
+		if( tags_key_exists(tags, *s) == FALSE )
+		{
+			*d = *s;
+			d++;
+			*d = 0;
+			DB( g_print(" - add %d\n", *s) );
+		}
+		else
+			DB( g_print(" - skip %d\n", *s) );
+		s++;
+		count++;
+	}
+
+	g_free(tmp);
+}
+
+
+static void
+tags_move(guint32 *tags, guint32 key1, guint32 key2)
+{
+guint count = 0;
+guint countdup = 0;
+guint32 *p;
+
+	if( tags == NULL )
+		return;
+
+	DB( g_print("\n[tags] move\n") );
+
+	p = tags;
+	while(*p != 0 && count < 32)
+	{
+		if( *p == key1 )
+		{
+			*p = key2;
+		}
+
+		//count potential duplicate
+		if( *p == key2)
+			countdup++;
+
+		p++;
+		count++;
+	}
+
+	//TODO: ensure no duplicate on key2
+	if( countdup )
+		tags_deduplicate(tags);
+
+}
+
+
 guint32 *
 tags_parse(const gchar *tagstring)
 {
@@ -388,6 +465,36 @@ da_tag_debug_list(void)
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
+
+void
+tag_move(guint32 key1, guint32 key2)
+{
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
+
+	DB( g_print("\n[tag] move %d => %d\n", key1, key2) );
+
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
+
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
+		{
+		Transaction *txn = lnk_txn->data;
+
+			tags_move(txn->tags, key1, key2);
+			lnk_txn = g_list_next(lnk_txn);
+		}
+		lnk_acc = g_list_next(lnk_acc);
+	}
+	g_list_free(lst_acc);
+
+}
+
+
 gboolean
 tag_rename(Tag *item, const gchar *newname)
 {
@@ -395,6 +502,8 @@ Tag *existitem;
 gchar *stripname;
 gboolean retval = FALSE;
 
+	DB( g_print("\n[tag] rename\n") );
+	
 	stripname = g_strdup(newname);
 	g_strstrip(stripname);
 
