@@ -1096,6 +1096,8 @@ Account *oacc, *nacc;
 			txn->kcur = nacc->kcur;
 			nacc->flags |= AF_CHANGED;
 			account_balances_add(txn);
+			//#1865083 src acc also changed (balance)
+			oacc->flags |= AF_CHANGED;
 			return TRUE;
 		}
 		else
