@@ -17,8 +17,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _HOMEBANK_H_
-#define _HOMEBANK_H_
+#ifndef __HOMEBANK_H__
+#define __HOMEBANK_H__
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -73,15 +73,15 @@
 #define HB_UNSTABLE_SHOW	FALSE
 
 
-#define HB_VERSION_MAJOR	5
-#define HB_VERSION_MINOR	3
-#define HB_VERSION_MICRO	2
+#define HOMEBANK_MAJOR	5
+#define HOMEBANK_MINOR	4
+#define HOMEBANK_MICRO	1
 
-#define HB_VERSION		"5.3.2"
-#define HB_VERSION_NUM	(HB_VERSION_MAJOR*10000) + (HB_VERSION_MINOR*100) + HB_VERSION_MICRO
+#define HB_VERSION		"5.4.1"
+#define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.4
-#define PREF_VERSION		532
+#define PREF_VERSION		541
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
@@ -142,9 +142,9 @@ enum
 {
 	UF_TITLE     	= 1 << 0,	//1
 	UF_SENSITIVE 	= 1 << 1,	//2
-	UF_BALANCE   	= 1 << 2,	//4
-	UF_VISUAL    	= 1 << 3,	//8
-	UF_REFRESHALL	= 1 << 4	//16
+	UF_VISUAL   	= 1 << 2,	//4
+	UF_REFRESHALL   = 1 << 3,	//8
+//			= 1 << 4	//16
 };
 
 
