@@ -42,43 +42,50 @@
 extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 /* scheduled */
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
-static Archive *
-ui_hub_scheduled_get_selected_item(GtkTreeView *treeview)
-{
-GtkTreeSelection *treeselection;
-GtkTreeModel		 *model;
-GtkTreeIter			 iter;
-
-	treeselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-	if( gtk_tree_selection_get_selected(treeselection, &model, &iter) )
-	{
-	Archive *arc;
-
-		gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, LST_DSPUPC_DATAS, &arc, -1);
-		return arc;
-	}
-
-	return NULL;
-}
 
 
-static void ui_hub_scheduled_onRowActivated (GtkTreeView        *treeview,
+static void ui_hub_scheduled_onRowActivated (GtkTreeView *treeview,
                        GtkTreePath        *path,
                        GtkTreeViewColumn  *col,
                        gpointer            userdata)
 {
-//struct hbfile_data *data;
-Archive *arc;
+struct hbfile_data *data;
+GtkTreeModel *model;
+GList *selection, *list;
+gint count;
 
 	DB( g_print ("\n[hub-scheduled] row double-clicked\n") );
 
-	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(treeview, GTK_TYPE_WINDOW)), "inst_data");
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
 
-	arc = ui_hub_scheduled_get_selected_item(treeview);
-	ui_mainwindow_defarchive(arc);
+	count = gtk_tree_selection_count_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)));
+	if( count == 1 )
+	{
+		//model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_upc));
+		selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)), &model);
+
+		list = g_list_first(selection);
+		if(list != NULL)
+		{
+		GtkTreeIter iter;
+		Archive *arc;
+
+			gtk_tree_model_get_iter(model, &iter, list->data);
+			gtk_tree_model_get(model, &iter, LST_DSPUPC_DATAS, &arc, -1);
+
+			//fix: don't open for total line
+			if( arc != NULL )
+				ui_mainwindow_defarchive(arc);
+
+		}
+
+		g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+		g_list_free(selection);
+	}
 }
 
 
@@ -127,74 +134,131 @@ Transaction *txn;
 static void ui_hub_scheduled_editpost_cb(GtkWidget *widget, gpointer user_data)
 {
 struct hbfile_data *data = user_data;
-
+GtkTreeModel *model;
+GList *selection, *list;
+	
 	DB( g_print("\n[hub-scheduled] editpost\n") );
 	
-	Archive *arc = ui_hub_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
+	selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)), &model);
 
-	if( (arc != NULL) )
+	list = g_list_first(selection);
+	while(list != NULL)
 	{
-		ui_hub_scheduled_do_post(arc, TRUE, data);
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
+	GtkTreeIter iter;
+	Archive *arc;
+
+		gtk_tree_model_get_iter(model, &iter, list->data);
+		gtk_tree_model_get(model, &iter, LST_DSPUPC_DATAS, &arc, -1);
+
+		if( (arc != NULL) )
+		{
+			ui_hub_scheduled_do_post(arc, TRUE, data);
+		}
+
+		list = g_list_next(list);
 	}
+
+	g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free(selection);
+
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
+
 }
 
 
 static void ui_hub_scheduled_post_cb(GtkWidget *widget, gpointer user_data)
 {
 struct hbfile_data *data = user_data;
-
+GtkTreeModel *model;
+GList *selection, *list;
+	
 	DB( g_print("\n[hub-scheduled] post\n") );
 
-	Archive *arc = ui_hub_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
+	selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)), &model);
 
-	if( (arc != NULL) )
+	list = g_list_first(selection);
+	while(list != NULL)
 	{
-		if( scheduled_is_postable(arc) )
+	GtkTreeIter iter;
+	Archive *arc;
+
+		gtk_tree_model_get_iter(model, &iter, list->data);
+		gtk_tree_model_get(model, &iter, LST_DSPUPC_DATAS, &arc, -1);
+	
+		if( (arc != NULL) )
 		{
-		Transaction *txn = da_transaction_malloc ();
+			if( scheduled_is_postable(arc) )
+			{
+			Transaction *txn = da_transaction_malloc ();
 
-			da_transaction_init_from_template(txn, arc);
-			txn->date = scheduled_get_postdate(arc, arc->nextdate);
-			transaction_add(GTK_WINDOW(GLOBALS->mainwindow), txn);
+				da_transaction_init_from_template(txn, arc);
+				txn->date = scheduled_get_postdate(arc, arc->nextdate);
+				transaction_add(GTK_WINDOW(GLOBALS->mainwindow), txn);
 
-			GLOBALS->changes_count++;
-			scheduled_date_advance(arc);
+				GLOBALS->changes_count++;
+				scheduled_date_advance(arc);
+
+				da_transaction_free (txn);
+			}
+			else
+			{
+				ui_hub_scheduled_do_post(arc, FALSE, data);
+			}
 
-			da_transaction_free (txn);
-		}
-		else
-		{
-			ui_hub_scheduled_do_post(arc, FALSE, data);
 		}
 
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
+		list = g_list_next(list);
 	}
+
+	g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free(selection);
+
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
+	
 }
 
 
 static void ui_hub_scheduled_skip_cb(GtkWidget *widget, gpointer user_data)
 {
 struct hbfile_data *data = user_data;
-
-	DB( g_print("\n[hub-scheduled] skip\n") );
+GtkTreeModel *model;
+GList *selection, *list;
 	
-	Archive *arc = ui_hub_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
-	if( (arc != NULL) && (arc->flags & OF_AUTO) )
+	DB( g_print("\n[hub-scheduled] skip\n") );
+
+	selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)), &model);
+
+	list = g_list_first(selection);
+	while(list != NULL)
 	{
-		GLOBALS->changes_count++;
-		scheduled_date_advance(arc);
+	GtkTreeIter iter;
+	Archive *arc;
 
-		ui_hub_scheduled_populate(GLOBALS->mainwindow, NULL);
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+		gtk_tree_model_get_iter(model, &iter, list->data);
+		gtk_tree_model_get(model, &iter, LST_DSPUPC_DATAS, &arc, -1);
+
+		if( (arc != NULL) && (arc->flags & OF_AUTO) )
+		{
+			GLOBALS->changes_count++;
+			scheduled_date_advance(arc);
+
+			ui_hub_scheduled_populate(GLOBALS->mainwindow, NULL);
+		}
+		
+		list = g_list_next(list);
 	}
-}
 
+	g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free(selection);
+
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+}
 
 
 static void ui_hub_scheduled_update(GtkWidget *widget, gpointer user_data)
 {
 struct hbfile_data *data;
+gint count;
 //gint filter;
 
 	DB( g_print("\n[hub-scheduled] update\n") );
@@ -203,11 +267,13 @@ struct hbfile_data *data;
 
 	//filter = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_sched_filter));
 
-	Archive *arc = ui_hub_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
+	count = gtk_tree_selection_count_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)));
 
-	if(arc)
+	//Archive *arc = ui_hub_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
+
+	if(count >= 1)
 	{
-		DB( g_print("archive is %s\n", arc->memo) );
+		//DB( g_print("archive is %s\n", arc->memo) );
 		
 		gtk_widget_set_sensitive(GTK_WIDGET(data->BT_sched_skip), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(data->BT_sched_post), TRUE);
