@@ -992,7 +992,7 @@ GtkTreeViewColumn *column;
 gint i, col_id;
 
  
-	if( ev->button == 3 )
+	if (ev->type == GDK_BUTTON_PRESS && ev->button == 3)
 	{
 		DB( g_print("should popup\n") );
 	
