@@ -59,6 +59,7 @@ static void repbudget_toggle(GtkWidget *widget, gpointer user_data);
 static GtkWidget *create_list_budget(void);
 static void repbudget_update_detail(GtkWidget *widget, gpointer user_data);
 static void repbudget_update_daterange(GtkWidget *widget, gpointer user_data);
+static void repbudget_update_chart(GtkWidget *widget, gpointer user_data);
 
 static GString *ui_list_repbudget_to_string(GtkTreeView *treeview, gboolean clipboard);
 
@@ -80,6 +81,9 @@ static void repbudget_action_viewstack(GtkToolButton *toolbutton, gpointer user_
 {
 struct repbudget_data *data = user_data;
 
+	//#1860905 we redraw chart in case a sort changed
+	repbudget_update_chart(data->window, NULL);
+	
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(data->GR_result), 1);
 	repbudget_sensitive(data->window, NULL);
 }
@@ -575,6 +579,33 @@ Category *cat;
 }
 
 
+static void repbudget_update_chart(GtkWidget *widget, gpointer user_data)
+{
+struct repbudget_data *data;
+GtkTreeModel *model;
+gint tmpfor;
+gchar *title;
+	
+	DB( g_print("\n[repbudget] update chart\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	tmpfor = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report));
+	
+	/* update stack chart */
+	title = g_strdup_printf(_("Budget for %s"), _(CYA_CATSUBCAT[tmpfor]) );
+
+	ui_chart_progress_set_currency(GTK_CHARTPROGRESS(data->RE_stack), GLOBALS->kcur);
+
+	/* set chart color scheme */
+	ui_chart_progress_set_color_scheme(GTK_CHARTPROGRESS(data->RE_stack), PREFS->report_color_scheme);
+	ui_chart_progress_set_dualdatas(GTK_CHARTPROGRESS(data->RE_stack), model, _("Budget"), _("Result"), title, NULL);
+
+	g_free(title);
+}
+
+
 static void repbudget_compute(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
@@ -589,7 +620,7 @@ guint n_result, id;
 gdouble *tmp_spent, *tmp_budget;
 gboolean *tmp_hassub;
 gint nbmonth = 1;
-gchar *title;
+
 
 	DB( g_print("\n[repbudget] compute\n") );
 
@@ -835,16 +866,7 @@ gchar *title;
 
 		repbudget_update_total(widget, NULL);
 
-		/* update stack chart */
-		title = g_strdup_printf(_("Budget for %s"), _(CYA_CATSUBCAT[tmpfor]) );
-
-		ui_chart_progress_set_currency(GTK_CHARTPROGRESS(data->RE_stack), GLOBALS->kcur);
-
-		/* set chart color scheme */
-		ui_chart_progress_set_color_scheme(GTK_CHARTPROGRESS(data->RE_stack), PREFS->report_color_scheme);
-		ui_chart_progress_set_dualdatas(GTK_CHARTPROGRESS(data->RE_stack), model, _("Budget"), _("Result"), title, NULL);
-
-		g_free(title);
+		repbudget_update_chart(widget, NULL);
 	}
 
 	//DB( g_print(" inserting %i, %f %f\n", i, total_expense, total_income) );
@@ -1438,6 +1460,7 @@ const gchar *format;
 ** 0 if they are equal,
 ** or a positive integer if the first value comes after the second.
 */
+/*
 static gint budget_listview_compare_funct (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
 gint retval = 0;
@@ -1453,7 +1476,7 @@ gchar *entry1, *entry2;
 	g_free(entry1);
 
     return retval;
-}
+}*/
 
 
 static void budget_amount_cell_data_function (GtkTreeViewColumn *col,
@@ -1538,7 +1561,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, budget_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	//gtk_tree_view_column_set_sort_column_id (column, id);
+	gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
 
@@ -1580,7 +1603,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	//gtk_tree_view_column_set_cell_data_func(column, renderer, ope_result_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_add_attribute(column, renderer, "text", LST_BUDGET_NAME);
-	//gtk_tree_view_column_set_sort_column_id (column, LST_STAT_NAME);
+	gtk_tree_view_column_set_sort_column_id (column, LST_BUDGET_NAME);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
@@ -1606,14 +1629,16 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* sort */
-	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), budget_listview_compare_funct, NULL, NULL);
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+	//gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), budget_listview_compare_funct, NULL, NULL);
+	//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_BUDGET_NAME, GTK_SORT_ASCENDING);
 
 /*
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_POS   , stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_POS), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_NAME  , stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_POS), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_SPENT , stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_SPENT), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_BUDGET, stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_BUDGET), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_RESULT , stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_RESULT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_BUDGET_RESULT, stat_list_compare_func, GINT_TO_POINTER(LST_BUDGET_RESULT), NULL);
 */
 
 	return(view);
