@@ -260,13 +260,15 @@ GtkWidget *entry = user_data;
 GtkAllocation allocation;
 GtkPopover *popover;
 
+    DB( g_print ("[acc entry popover] open\n") );
+
 	if(GTK_IS_ENTRY(entry))
 	{
 		gtk_widget_get_allocation (entry, &allocation);
 		popover = gtk_menu_button_get_popover(GTK_MENU_BUTTON(togglebutton));
 		if(GTK_IS_POPOVER(popover))
 		{
-			gtk_widget_set_size_request (GTK_WIDGET(popover), allocation.width + (2*SPACING_POPOVER), -1);	
+			gtk_widget_set_size_request (GTK_WIDGET(popover), allocation.width + (2*SPACING_POPOVER), -1);
 			DB( g_print("should set width to %d\n", allocation.width + (2*SPACING_POPOVER)) );	
 		}
 	}
@@ -336,6 +338,7 @@ GtkEntryCompletion *completion;
 	gtk_widget_show_all(mainbox);
 
 
+	//popover
 	box = gtk_box_new(GTK_ORIENTATION_VERTICAL, SPACING_MEDIUM);
 	scrollwin = gtk_scrolled_window_new(NULL,NULL);
 	gtk_box_pack_start(GTK_BOX(box), scrollwin, TRUE, TRUE, 0);
@@ -383,7 +386,6 @@ GtkCellRenderer *renderer;
 	
 	gtk_menu_button_set_popover(GTK_MENU_BUTTON(menubutton), popover);
 	
-	
 	// connect our dispose function
 	g_signal_connect (entry, "destroy", G_CALLBACK (ui_acc_entry_popover_destroy), NULL);
 
@@ -857,6 +859,47 @@ next1:
 }
 
 
+static gboolean ui_acc_listview_search_equal_func (GtkTreeModel *model,
+                               gint column,
+                               const gchar *key,
+                               GtkTreeIter *iter,
+                               gpointer search_data)
+{
+gboolean retval = TRUE;
+gchar *normalized_string;
+gchar *normalized_key;
+gchar *case_normalized_string = NULL;
+gchar *case_normalized_key = NULL;
+Account *item;
+
+	DB( g_print(" search '%s'\n", key) );
+
+
+	gtk_tree_model_get(model, iter, LST_DEFACC_DATAS, &item, -1);
+
+	if(item !=  NULL)
+	{
+		normalized_string = g_utf8_normalize (item->name, -1, G_NORMALIZE_ALL);
+		normalized_key = g_utf8_normalize (key, -1, G_NORMALIZE_ALL);
+
+		if (normalized_string && normalized_key)
+		{
+			case_normalized_string = g_utf8_casefold (normalized_string, -1);
+			case_normalized_key = g_utf8_casefold (normalized_key, -1);
+
+			if (strncmp (case_normalized_key, case_normalized_string, strlen (case_normalized_key)) == 0)
+				retval = FALSE;
+		}
+
+		g_free (normalized_key);
+		g_free (normalized_string);
+		g_free (case_normalized_key);
+		g_free (case_normalized_string);
+	}
+	return retval;
+}
+
+
 GtkWidget *
 ui_acc_listview_new(gboolean withtoggle)
 {
@@ -913,6 +956,8 @@ GtkTreeViewColumn	*column;
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(treeview), ui_acc_listview_search_equal_func, NULL, NULL);
+
 	// treeviewattribute
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeview), !withtoggle);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW(treeview), TRUE);
@@ -1689,7 +1734,7 @@ GtkWidget *dialog, *content, *mainbox, *vbox, *scrollwin, *notebook;
 GtkWidget *content_grid, *group_grid, *tbar, *bbox;
 GtkWidget *label, *widget, *hpaned;
 GtkToolItem *toolitem;
-gint w, h, row;
+gint w, h, dw, dh, row;
 
 	data = g_malloc0(sizeof(struct ui_acc_manage_data));
 	if(!data) return NULL;
@@ -1708,8 +1753,12 @@ gint w, h, row;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
-
+	dh = (h*1.33/PHI);
+	//ratio 1:1
+	dw = (dh * 1) / 1;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
+	
 	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("(ui_acc_manage_) dialog=%p, inst_data=%p\n", dialog, data) );
