@@ -813,7 +813,7 @@ GtkWidget *table, *label, *entry1;
 GtkWidget *scrollwin, *vbox, *bbox, *tbar;
 GtkWidget *widget, *hpaned;
 GtkToolItem *toolitem;
-gint w, h, crow, row;
+gint w, h, dw, dh, crow, row;
 
 	data = g_malloc0(sizeof(struct ui_asg_manage_data));
 	if(!data) return NULL;
@@ -832,8 +832,13 @@ gint w, h, crow, row;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
-	
+	dh = (h*1.33/PHI);
+	//ratio 3:2
+	dw = (dh * 3) / 2;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
+
+
 	//store our window private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("(ui_asg_manage_) window=%x, inst_data=%x\n", (guint)dialog, (guint)data) );
