@@ -730,6 +730,17 @@ struct catPopContext ctx;
 }
 
 
+void
+ui_cat_combobox_entry_clear(GtkComboBox *entry_box)
+{
+GtkTreeModel *model;
+
+    DB( g_print ("ui_cat_comboboxentry_clear()\n") );
+
+	model = gtk_combo_box_get_model(GTK_COMBO_BOX(entry_box));
+	gtk_list_store_clear (GTK_LIST_STORE(model));
+}
+
 
 static gint
 ui_cat_comboboxentry_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata)
@@ -1320,12 +1331,12 @@ static gboolean ui_cat_listview_search_equal_func (GtkTreeModel *model,
                                GtkTreeIter *iter,
                                gpointer search_data)
 {
-  gboolean retval = TRUE;
-  gchar *normalized_string;
-  gchar *normalized_key;
-  gchar *case_normalized_string = NULL;
-  gchar *case_normalized_key = NULL;
-  Category *item;
+gboolean retval = TRUE;
+gchar *normalized_string;
+gchar *normalized_key;
+gchar *case_normalized_string = NULL;
+gchar *case_normalized_key = NULL;
+Category *item;
 	
   //gtk_tree_model_get_value (model, iter, column, &value);
   gtk_tree_model_get(model, iter, LST_DEFCAT_DATAS, &item, -1);
@@ -2191,40 +2202,43 @@ static void ui_cat_manage_type_changed_cb (GtkToggleButton *button, gpointer use
 GtkWidget *ui_cat_manage_dialog (void)
 {
 struct ui_cat_manage_dialog_data *data;
-GtkWidget *window, *content, *mainvbox, *bbox, *table, *hbox, *vbox, *label, *scrollwin, *treeview;
+GtkWidget *dialog, *content, *mainvbox, *bbox, *table, *hbox, *vbox, *label, *scrollwin, *treeview;
 GtkWidget *menu, *menuitem, *widget, *image, *tbar, *addreveal;
 GtkToolItem *toolitem;
-gint w, h, row;
+gint w, h, dw, dh, row;
 
 	data = g_malloc0(sizeof(struct ui_cat_manage_dialog_data));
 	if(!data) return NULL;
 
-	window = gtk_dialog_new_with_buttons (_("Manage Categories"),
+	dialog = gtk_dialog_new_with_buttons (_("Manage Categories"),
 					    GTK_WINDOW(GLOBALS->mainwindow),
 					    0,
 					    _("_Close"),
 					    GTK_RESPONSE_ACCEPT,
 					    NULL);
 
-	data->dialog = window;
+	data->dialog = dialog;
 	data->change = 0;
 
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_CATEGORY);
+	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_CATEGORY);
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(window), -1, h/PHI);
-
+	dh = (h*1.33/PHI);
+	//ratio 2:3
+	dw = (dh * 2) / 3;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 	
 	//store our window private data
-	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
-	DB( g_print("(defcategory) window=%p, inst_data=%p\n", window, data) );
+	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
+	DB( g_print("(defcategory) dialog=%p, inst_data=%p\n", dialog, data) );
 
-    g_signal_connect (window, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &window);
+    g_signal_connect (dialog, "destroy",
+			G_CALLBACK (gtk_widget_destroyed), &dialog);
 
-	//window contents
-	content = gtk_dialog_get_content_area(GTK_DIALOG (window));
+	//dialog contents
+	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
@@ -2387,10 +2401,10 @@ gint w, h, row;
 	ui_cat_manage_dialog_setup(data);
 	ui_cat_manage_dialog_update(data->LV_cat, NULL);
 
-	gtk_widget_show_all (window);
+	gtk_widget_show_all (dialog);
 
 	//wait for the user
-	gint result = gtk_dialog_run (GTK_DIALOG (window));
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	switch (result)
     {
@@ -2407,7 +2421,7 @@ gint w, h, row;
 	GLOBALS->changes_count += data->change;
 
 	ui_cat_manage_dialog_cleanup(data, result);
-	gtk_widget_destroy (window);
+	gtk_widget_destroy (dialog);
 
 	g_free(data);
 
