@@ -167,10 +167,10 @@ va_list args;
 
 void ui_dialog_file_statistics(void)
 {
-GtkWidget *dialog, *content_area, *content_grid, *group_grid;
+GtkWidget *dialog, *content_area, *box, *group_grid;
 GtkWidget *label, *widget;
-gchar *tmpstr;
-gint crow, row, count;
+//gchar *tmpstr;
+gint row, count, count2;
 
 	dialog = gtk_dialog_new_with_buttons (_("File statistics"),
 		GTK_WINDOW (GLOBALS->mainwindow),
@@ -183,24 +183,15 @@ gint crow, row, count;
 	
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
-	content_grid = gtk_grid_new();
-	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
-	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
-	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
-	gtk_box_pack_start (GTK_BOX (content_area), content_grid, TRUE, TRUE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(box), SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (content_area), box, FALSE, FALSE, 0);
 
-	crow = 0;
 	// group :: file title
     group_grid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
-	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
-
-	label = make_label_group(NULL);
-	tmpstr = g_path_get_basename(GLOBALS->xhb_filepath);
-	gtk_label_set_text(GTK_LABEL(label), tmpstr);
-	g_free(tmpstr);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
+	gtk_box_pack_start (GTK_BOX (box), group_grid, FALSE, FALSE, 0);
 
 	row = 1;
 	label = make_label_widget(_("Account"));
@@ -220,7 +211,44 @@ gint crow, row, count;
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
+	da_archive_stats(&count, &count2);
+
 	row++;
+	label = make_label_widget(_("Scheduled"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_label(NULL, 1.0, 0.5);
+	ui_label_set_integer(GTK_LABEL(widget), count2);
+	gtk_widget_set_hexpand(widget, TRUE);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	row++;
+	label = make_label_widget(_("Template"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_label(NULL, 1.0, 0.5);
+	ui_label_set_integer(GTK_LABEL(widget), count);
+	gtk_widget_set_hexpand(widget, TRUE);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	row++;
+	label = make_label_widget(_("Assignment"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_label(NULL, 1.0, 0.5);
+	count = da_asg_length ();
+	ui_label_set_integer(GTK_LABEL(widget), count);
+	gtk_widget_set_hexpand(widget, TRUE);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+
+	widget = gtk_separator_new(	GTK_ORIENTATION_VERTICAL);
+	gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
+
+	// group :: file title
+    group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (box), group_grid, FALSE, FALSE, 0);
+
+	row = 1;
 	label = make_label_widget(_("Payee"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
@@ -239,15 +267,25 @@ gint crow, row, count;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label_widget(_("Assignment"));
+	label = make_label_widget(_("Tag"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
-	count = da_asg_length ();
+	count = da_tag_length ();
 	ui_label_set_integer(GTK_LABEL(widget), count);
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
-	gtk_widget_show_all(content_grid);
+	row++;
+	label = make_label_widget(_("Currency"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_label(NULL, 1.0, 0.5);
+	count = da_cur_length ();
+	ui_label_set_integer(GTK_LABEL(widget), count);
+	gtk_widget_set_hexpand(widget, TRUE);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	
+	gtk_widget_show_all(box);
 
 	//wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -566,18 +604,22 @@ gboolean retval;
 					button, GTK_RESPONSE_ACCEPT,
 					NULL);
 
-	if( bakmode == FALSE )
+	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
 	{
-		ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("HomeBank files"), "*.[Xx][Hh][Bb]");
-		ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All files"), "*");
-	}
-	else
-	{
-		if( (action == GTK_FILE_CHOOSER_ACTION_OPEN) )
+		if( bakmode == FALSE )
+		{
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_hbfile);
+			ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("HomeBank files"), "*.[Xx][Hh][Bb]");
+			ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All files"), "*");
+		}
+		else
 		{
 		gchar *pattern;
 		GtkFileFilter *flt;
 
+			//#1864176 open backup should open the backup folder
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_hbbak);
+
 			pattern = hb_filename_backup_get_filtername(GLOBALS->xhb_filepath);
 			flt = ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("File backup"), pattern);
 			gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), flt);
@@ -586,12 +628,7 @@ gboolean retval;
 			ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All backups"), "*.[Bb][Aa][Kk]");
 		}
 	}
-	
-	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
-	{
-	    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_hbfile);
-	}
-	else /* save */
+	else /* GTK_FILE_CHOOSER_ACTION_SAVE */
 	{
 	gchar *basename, *dirname;
 		
@@ -618,6 +655,7 @@ gboolean retval;
 	return retval;
 }
 
+
 /*
 **
 */
@@ -762,10 +800,12 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
 
 	row = 0;
+	/*
 	widget = gtk_image_new_from_icon_name (ICONNAME_WARNING, GTK_ICON_SIZE_DIALOG);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 0, row, 1, 1);
 	label = gtk_label_new("This feature is still in development state,\n(maybe not stable) so use it at your own risk!");
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	*/
 
 	row++;
 	label = make_label_widget(_("Folder:"));
@@ -777,8 +817,18 @@ gint crow, row;
 	label = make_label_widget(_("Filename:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
 	ST_name = make_string (label);
+	gtk_widget_set_hexpand(ST_name, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), ST_name, 1, row, 1, 1);
 
+	row++;
+	row++;
+	widget = gtk_image_new_from_icon_name (ICONNAME_INFO, GTK_ICON_SIZE_DIALOG);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 0, row, 1, 1);
+	//                       123456789012345678901234567890123456789012345678901234567890
+	label = gtk_label_new(_("With HomeBank, printing is oriented towards an eco-responsible\n" \
+							"attitude towards the most widespread digital format: PDF format. "));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+
 
 	//setup
 	tmpstr = g_path_get_dirname(*storage_ptr);
