@@ -117,7 +117,7 @@ Category *cat;
 }
 
 
-static void list_split_populate(struct ui_split_dialog_data *data)
+static void list_split_populate(GtkWidget *treeview, GPtrArray *splits)
 {
 GtkTreeModel *model;
 GtkTreeIter	iter;
@@ -126,22 +126,22 @@ gint count, i;
 
 	DB( g_print("\n[list_split] populate\n") );
 
-	count = da_splits_length (data->tmp_splits);
+	count = da_splits_length (splits);
 
 	if( count <= 0 )
 		return;
 
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_split));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 
 	gtk_list_store_clear (GTK_LIST_STORE(model));
 
 	g_object_ref(model); /* Make sure the model stays with us after the tree view unrefs it */
-	gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_split), NULL); /* Detach model from view */
+	gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), NULL); /* Detach model from view */
 
 	/* populate */
 	for(i=0 ; i < count ; i++)
 	{
-		split = da_splits_get(data->tmp_splits, i);
+		split = da_splits_get(splits, i);
 
 		DB( g_print("- set split %d : %d, %.2f, %s\n", i, split->kcat, split->amount, split->memo) );
 
@@ -152,14 +152,11 @@ gint count, i;
 
 	}
 
-	gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_split), model); /* Re-attach model to view */
+	gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), model); /* Re-attach model to view */
 	g_object_unref(model);
 }
 
 
-
-
-
 static GtkWidget *
 list_split_new(void)
 {
@@ -197,6 +194,8 @@ GtkTreeViewColumn	*column;
 	g_object_set(renderer, 
 		"ellipsize", PANGO_ELLIPSIZE_END,
 	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
 	    NULL);
 	
 	column = gtk_tree_view_column_new_with_attributes(_("Category"), renderer, NULL);
@@ -215,6 +214,8 @@ GtkTreeViewColumn	*column;
 	g_object_set(renderer, 
 		"ellipsize", PANGO_ELLIPSIZE_END,
 	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
 	    NULL);
 	
 	column = gtk_tree_view_column_new_with_attributes(_("Memo"), renderer, NULL);
@@ -326,25 +327,23 @@ guint i;
 static void ui_split_dialog_cb_eval_split(GtkWidget *widget, gpointer user_data)
 {
 struct ui_split_dialog_data *data;
-gboolean tmpval = FALSE;
+gboolean sensitive;
 gdouble amount;
-gint count;
+guint count;
 	
 	DB( g_print("\n[ui_split_dialog] eval split\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
 	amount = g_strtod(gtk_entry_get_text(GTK_ENTRY(data->ST_amount)), NULL);
+	sensitive = hb_amount_round(amount, 2) != 0.0 ? TRUE : FALSE;
+	gtk_widget_set_sensitive (data->BT_apply, sensitive);
 
-	tmpval = hb_amount_round(amount, 2) != 0.0 ? TRUE : FALSE;
-	gtk_widget_set_sensitive (data->BT_apply, tmpval);
+	count = da_splits_length (data->tmp_splits);
+	sensitive = ( count >= TXN_MAX_SPLIT ) ? FALSE : TRUE;
+	gtk_widget_set_sensitive (data->BT_add, sensitive);
 
-	count = gtk_tree_model_iter_n_children(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_split)), NULL);
-	if( count >= TXN_MAX_SPLIT )
-		tmpval = FALSE;
-	gtk_widget_set_sensitive (data->BT_add, tmpval);
-
-	DB( g_print(" - txt='%s' amt=%.2f, nbsplit=%d, valid=%d\n", gtk_entry_get_text(GTK_ENTRY(data->ST_amount)), amount, count, tmpval) );
+	DB( g_print(" - txt='%s' amt=%.2f, nbsplit=%d\n", gtk_entry_get_text(GTK_ENTRY(data->ST_amount)), amount, count) );
 
 }
 
@@ -450,7 +449,6 @@ GtkTreeIter			 iter;
 }
 
 
-
 static void ui_split_dialog_cancel_cb(GtkWidget *widget, gpointer user_data)
 {
 //struct ui_split_dialog_data *data;
@@ -730,7 +728,7 @@ guint count;
 	data->nbsplit = count > 1 ? count-1 : 0;
 
 	DB( g_print("- count = %d\n", count) );
-	list_split_populate (data);
+	list_split_populate (data->LV_split, data->tmp_splits);
 
 	data->isedited = FALSE;
 
@@ -741,6 +739,73 @@ guint count;
 }
 
 
+GtkWidget *ui_split_view_dialog (GtkWidget *parent, Transaction *ope)
+{
+GtkWidget *dialog, *content, *table, *scrollwin, *treeview;
+gint w, h, dw, dh, row;
+
+	DB( g_print("\n[ui_split_dialog] new view only\n") );
+
+	if( ope->splits == NULL )
+		return NULL;
+	
+	dialog = gtk_dialog_new_with_buttons (_("Transaction splits"),
+					    GTK_WINDOW(parent),
+					    0,
+					    _("_Close"),
+					    GTK_RESPONSE_ACCEPT,
+					    NULL);
+
+	//store our dialog private data
+	DB( g_print(" - window=%p\n", dialog) );
+
+    g_signal_connect (dialog, "destroy",
+			G_CALLBACK (gtk_widget_destroyed), &dialog);
+
+	//set a nice dialog size
+	gtk_window_get_size(GTK_WINDOW(parent), &w, &h);
+	dh = (h/PHI);
+	//ratio 3:2
+	dw = (dh * 3) / 2;
+	DB( g_print(" parent w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
+
+	
+	//dialog contents
+	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
+
+	table = gtk_grid_new ();
+	gtk_container_set_border_width (GTK_CONTAINER (table), SPACING_SMALL);
+	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_TINY);
+	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_TINY);
+	gtk_box_pack_start (GTK_BOX (content), table, TRUE, TRUE, 0);
+
+	row = 0;
+
+	scrollwin = gtk_scrolled_window_new(NULL,NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
+	gtk_widget_set_size_request(scrollwin, HB_MINWIDTH_LIST, HB_MINHEIGHT_LIST);
+	gtk_widget_set_hexpand (scrollwin, TRUE);
+	gtk_widget_set_vexpand (scrollwin, TRUE);
+	treeview = list_split_new();
+	gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
+	gtk_grid_attach (GTK_GRID (table), scrollwin, 0, row, 4, 1);
+
+	//setup
+	list_split_populate(treeview, ope->splits);
+	
+	gtk_widget_show_all (dialog);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
+	
+	return NULL;
+	
+}
+
+
 GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits, gint txntype, gdouble amount, void (update_callbackFunction(GtkWidget*, gdouble)))
 {
 struct ui_split_dialog_data *data;
