@@ -261,33 +261,43 @@ struct deftransaction_data *data;
 gdouble amount;
 Account *acc;
 guint cheque;
+gint paymode;
 gchar *cheque_str;
 
 	DB( g_print("\n[ui-transaction] set_cheque\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-	if( amount < 0 )
+	if( data->action != TXN_DLG_ACTION_EDIT )
 	{
-		//acc = ui_acc_comboboxentry_get(GTK_COMBO_BOX(data->PO_acc));
-		acc = ui_acc_entry_popover_get(GTK_BOX(data->PO_acc));
-		//#1410166
-		if(acc != NULL)
+		paymode = paymode_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
+		if(paymode == PAYMODE_CHECK)
 		{
-			DB( g_print(" - should fill for acc %d '%s'\n", acc->key, acc->name) );
+			amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+			if( amount < 0 )
+			{
+				//acc = ui_acc_comboboxentry_get(GTK_COMBO_BOX(data->PO_acc));
+				acc = ui_acc_entry_popover_get(GTK_BOX(data->PO_acc));
+				//#1410166
+				if(acc != NULL)
+				{
+					DB( g_print(" - should fill for acc %d '%s'\n", acc->key, acc->name) );
+
+					cheque = ( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_cheque))==TRUE ? acc->cheque2 : acc->cheque1 );
+					cheque_str = g_strdup_printf("%d", cheque + 1);
+					gtk_entry_set_text(GTK_ENTRY(data->ST_info), cheque_str);
+					g_free(cheque_str);
+				}
+			}
+			else
+			if( amount > 0 )
+			{
+				gtk_entry_set_text(GTK_ENTRY(data->ST_info), "");
+			}
 
-			cheque = ( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_cheque))==TRUE ? acc->cheque2 : acc->cheque1 );
-			cheque_str = g_strdup_printf("%d", cheque + 1);
-			gtk_entry_set_text(GTK_ENTRY(data->ST_info), cheque_str);
-			g_free(cheque_str);
 		}
 	}
-	else
-	if( amount > 0 )
-	{
-		gtk_entry_set_text(GTK_ENTRY(data->ST_info), "");
-	}
+
 }
 
 
@@ -443,7 +453,10 @@ gboolean change;
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), amount *= -1);
 			g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
 		}
-			
+		
+		//#1872329 fill-in cheque if condition match
+		deftransaction_set_cheque(widget, NULL);
+		
 		DB( g_print(" - call warnsign\n") );
 		deftransaction_update_warnsign(widget, NULL);
 	}
@@ -510,13 +523,7 @@ gboolean visible;
 	hb_widget_visible(data->CM_cheque, visible);
 	
 	/* todo: prefill the cheque number ? */
-	if( data->action != TXN_DLG_ACTION_EDIT )
-	{
-		if(paymode == PAYMODE_CHECK)
-		{
-			deftransaction_set_cheque(widget, user_data);
-		}
-	}
+	deftransaction_set_cheque(widget, user_data);
 }
 
 
@@ -824,7 +831,7 @@ Account *acc;
 				break_result = ui_dialog_msg_confirm_alert(
 						GTK_WINDOW(parent),
 						NULL,
-						_("Do you want to break the internal transfer ?\n\n"
+						_("Do you want to break the internal transfer?\n\n"
 						  "Proceeding will delete the target transaction."),
 						_("_Break")
 					);
@@ -923,6 +930,7 @@ static void deftransaction_setup(struct deftransaction_data *data)
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 static void ui_popover_tpl_onRowActivated(GtkTreeView        *treeview,
@@ -958,6 +966,22 @@ GtkTreeIter			 iter;
 }
 
 
+static gint
+ui_popover_tpl_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
+{
+gint retval = 0;
+Archive *entry1, *entry2;
+
+    gtk_tree_model_get(model, a, LST_DSPTPL_DATAS, &entry1, -1);
+    gtk_tree_model_get(model, b, LST_DSPTPL_DATAS, &entry2, -1);
+
+	retval = hb_string_utf8_compare(entry1->memo, entry2->memo);
+	
+    return retval;
+}
+
+
+
 
 static void ui_popover_tpl_populate(struct deftransaction_data *data, GList *srclist)
 {
@@ -1070,9 +1094,13 @@ GtkWidget *box, *widget, *scrollwin, *treeview;
 	store = gtk_list_store_new(NUM_LST_DSPTPL, 
 		G_TYPE_POINTER,
 		G_TYPE_STRING);
-		
+
 	data->model = GTK_TREE_MODEL(store);
-	
+
+	//#1865361 txn dialog template list switch sort order on each save
+	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), ui_popover_tpl_compare_func, NULL, NULL);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+
 	data->modelfilter = GTK_TREE_MODEL_FILTER(gtk_tree_model_filter_new(GTK_TREE_MODEL(data->model), NULL));
 	gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(data->modelfilter), ui_popover_tpl_func_visible, data, NULL);
 
